{% extends 'NearBeach/template.html' %}
{% block content %}
    <dashboard-rfc-approvals></dashboard-rfc-approvals>
    <dashboard-my-objects></dashboard-my-objects>
<!--    <dashboard-bug-list></dashboard-bug-list>-->
{% endblock %}
