{% include 'NearBeach/partials/header.html' %}
<main class="container" role="main">
    <div id="app">
        {% if user.is_authenticated %}
            {% block content %}
            {% endblock %}
        {% else %}
            <h1>Permission denied</h1>
            <p>You currently do not have permission to view this page!</p>
        {% endif %}
    </div>
</main>
{% include 'NearBeach/partials/footer.html' %}
