{% extends 'NearBeach/template.html' %}
{% load static %}
{% block content %}
    <group-information v-bind:group-results="{{group_results}}"
                       v-bind:parent-group-results="{{parent_group_results}}"
    ></group-information>

    <br/>
    <user-list v-bind:user-list-results="{{user_list_results}}"
               v-bind:destination="'group'"
               v-bind:location-id="{{group_id}}"
    ></user-list>
{% endblock %}