{% extends 'NearBeach/template.html' %}
{% load static %}
{% block content %}
    <new-customer v-bind:organisation-id="0"
                  v-bind:title-list="{{title_list}}"
                  v-bind:organisation-name="''"
    ></new-customer>
{% endblock %}
