# Generated by Django 3.1.2 on 2021-02-27 06:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('NearBeach', '0005_auto_20210123_1537'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='quote_product_and_service',
            name='change_user',
        ),
        migrations.RemoveField(
            model_name='quote_product_and_service',
            name='product_and_service',
        ),
        migrations.RemoveField(
            model_name='quote_product_and_service',
            name='quote',
        ),
        migrations.RemoveField(
            model_name='quote_product_and_service',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='quote_responsible_customer',
            name='change_user',
        ),
        migrations.RemoveField(
            model_name='quote_responsible_customer',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='quote_responsible_customer',
            name='quote',
        ),
        migrations.RemoveField(
            model_name='quote_template',
            name='change_user',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='assign_campus_to_customer',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='associate_project_and_task',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='bug',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='contact_history',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='email',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='invoice',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='invoice_product',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='opportunity',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='organisation_campus',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='quote',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='requirement_link',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='tag',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='tax',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='template',
        ),
        migrations.RemoveField(
            model_name='permission_set',
            name='whiteboard',
        ),
        migrations.DeleteModel(
            name='product_and_service',
        ),
        migrations.DeleteModel(
            name='quote_product_and_service',
        ),
        migrations.DeleteModel(
            name='quote_responsible_customer',
        ),
        migrations.DeleteModel(
            name='quote_template',
        ),
    ]
