{% extends "./NearBeach/template.html" %}
{% block content %}
<div class="alert alert-warning">
    <h1>404 - Page not found</h1>
    <hr>
    <p>I am sorry, this page either does not exist or you do not have permission to view it.</p>
</div>

{% endblock %}
