{% extends 'NearBeach/template.html' %}
{% load static %}
{% block content %}
    <customer-information v-bind:customer-results="{{customer_results}}"
                          v-bind:title-list="{{title_list}}"
                          v-bind:default-stakeholder-image="`{% static 'NearBeach/images/placeholder/product_tour.svg' %}`"
                          v-bind:organisation-results="{{organisation_results}}"
    ></customer-information>
{% endblock %}
