{% extends "./NearBeach/template.html" %}
{% block content %}

<div class="alert alert-danger">
    <h1>403 - Access Denied</h1>
    <hr>
    <p>You do not have access to this page.</p>
</div>
{% endblock %}
