# Generated by Django 3.1.2 on 2021-03-10 09:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('NearBeach', '0006_auto_20210227_1722'),
    ]

    operations = [
        migrations.AddField(
            model_name='kanban_card',
            name='kanban_card_description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
