<!DOCTYPE html>
<html lang="en">
<meta name="viewport" content="width=device-width, initial-scale=1">
<head>
    <meta charset="UTF-8">
    <title>NearBeach Login</title>

    <!-- Webpack file with Foundation -->
    {% load static %}
    <script defer
            src="{% static 'NearBeach/login.min.js' %}"
            id="login_script"
            data-static="{% static '' %}"
    ></script>
</head>
<body>
    <div class="background">
        <div class="login-dialog">
            <h1>Password Reset Done</h1>
            {% csrf_token %}

            <!-- Reset instructions -->
            <div>
                Please check your email for instructions to reset your password. <a href="{% url 'login' %}">Click here to go to the login screen.</a>
            </div>
        </div>
    </div>
</body>
</html>