# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2017-01-26 08:32
from __future__ import unicode_literals

from django.db import migrations


def initialise_data(apps, schema_editor):
    """
    The initial setup of the database should populate certain fields with
    the correct data. Otherwise certain features of the database will
    not function correctly.
    """
    db_alias = schema_editor.connection.alias

    # List of amount types
    list_of_amount_type = apps.get_model("NearBeach", "list_of_amount_type")
    list_of_amount_type.objects.using(db_alias).bulk_create([
        list_of_amount_type(amount_type_description="Fixed",list_order=0),
        list_of_amount_type(amount_type_description="Per Contract",list_order=1),
        list_of_amount_type(amount_type_description="Per Year",list_order=2),
        list_of_amount_type(amount_type_description="Per Month",list_order=3),
        list_of_amount_type(amount_type_description="Per Fortnight",list_order=4),
        list_of_amount_type(amount_type_description="Per Day",list_order=5),
        list_of_amount_type(amount_type_description="Per Hour",list_order=6),
    ])


    # List of bug clients
    list_of_bug_client = apps.get_model("NearBeach","list_of_bug_client")
    list_of_bug_client.objects.using(db_alias).bulk_create([
        list_of_bug_client(
            bug_client_name="Bugzilla",
            bug_client_api_url="/rest/",
            api_open_bugs="?open_status=True",
            api_search_bugs="bug?quicksearch=",
            api_bug="/show_bug.cgi?id=",
        )
    ])

    list_of_currency=apps.get_model("NearBeach","list_of_currency")
    list_of_currency.objects.using(db_alias).bulk_create([
        list_of_currency(currency_description='Australian dollar', currency_short_description='AUD', list_order='1'),
        list_of_currency(currency_description='Brazilian real', currency_short_description='BRL', list_order='2'),
        list_of_currency(currency_description='Canadian dollar', currency_short_description='CAD', list_order='3'),
        list_of_currency(currency_description='Euro', currency_short_description='EUR', list_order='4'),
        list_of_currency(currency_description='Hong Kong dollar', currency_short_description='HKD', list_order='5'),
        list_of_currency(currency_description='Indian rupee', currency_short_description='INR', list_order='6'),
        list_of_currency(currency_description='Japanese yen', currency_short_description='JPY', list_order='7'),
        list_of_currency(currency_description='Mexican peso', currency_short_description='MXN', list_order='8'),
        list_of_currency(currency_description='New Zealand dollar', currency_short_description='NZD', list_order='9'),
        list_of_currency(currency_description='Norwegian krone', currency_short_description='NOK', list_order='10'),
        list_of_currency(currency_description='Pound sterling', currency_short_description='GBP', list_order='11'),
        list_of_currency(currency_description='Renminbi', currency_short_description='CNY', list_order='12'),
        list_of_currency(currency_description='Russian ruble', currency_short_description='RUB', list_order='13'),
        list_of_currency(currency_description='Singapore dollar', currency_short_description='SGD', list_order='14'),
        list_of_currency(currency_description='South African rand', currency_short_description='ZAR', list_order='15'),
        list_of_currency(currency_description='South Korean won', currency_short_description='KRW', list_order='16'),
        list_of_currency(currency_description='Swedish krona', currency_short_description='SEK', list_order='17'),
        list_of_currency(currency_description='Swiss franc', currency_short_description='CHF', list_order='18'),
        list_of_currency(currency_description='Turkish lira', currency_short_description='TRY', list_order='19'),
        list_of_currency(currency_description='United States dollar', currency_short_description='USD',list_order='20'),
    ])

    list_of_lead_source=apps.get_model("NearBeach","list_of_lead_source")
    list_of_lead_source.objects.using(db_alias).bulk_create([
        list_of_lead_source(lead_source_description='Campaign', list_order='1'),
        list_of_lead_source(lead_source_description='Cold Call', list_order='2'),
        list_of_lead_source(lead_source_description='Conference', list_order='3'),
        list_of_lead_source(lead_source_description='Direct Mail', list_order='4'),
        list_of_lead_source(lead_source_description='Email', list_order='5'),
        list_of_lead_source(lead_source_description='Employee', list_order='6'),
        list_of_lead_source(lead_source_description='Existing Customer', list_order='7'),
        list_of_lead_source(lead_source_description='Partner', list_order='8'),
        list_of_lead_source(lead_source_description='Public Relations', list_order='9'),
        list_of_lead_source(lead_source_description='Self Generated', list_order='10'),
        list_of_lead_source(lead_source_description='Trade Show', list_order='11'),
        list_of_lead_source(lead_source_description='Web Site', list_order='12'),
        list_of_lead_source(lead_source_description='Word of mouth', list_order='13'),
        list_of_lead_source(lead_source_description='Other', list_order='14'),
    ])

    # List of contact types
    list_of_contact_types = apps.get_model("NearBeach", "list_of_contact_type")
    list_of_contact_types.objects.using(db_alias).bulk_create([
        list_of_contact_types(contact_type="Notes"),
        list_of_contact_types(contact_type="Phone"),
        list_of_contact_types(contact_type="Email"),
        list_of_contact_types(contact_type="Appointment"),

    ])

    list_of_opportunity_stage = apps.get_model("NearBeach", "list_of_opportunity_stage")
    list_of_opportunity_stage.objects.using(db_alias).bulk_create([
        list_of_opportunity_stage(list_order="1",opportunity_stage_description="Prospecting",probability_success="10"),
        list_of_opportunity_stage(list_order="2", opportunity_stage_description="Qualification",probability_success="20"),
        list_of_opportunity_stage(list_order="3", opportunity_stage_description="Needs Analysis",probability_success="30"),
        list_of_opportunity_stage(list_order="4", opportunity_stage_description="Value Proposition",probability_success="40"),
        list_of_opportunity_stage(list_order="5", opportunity_stage_description="Identifying Decision Makers",probability_success="50"),
        list_of_opportunity_stage(list_order="6", opportunity_stage_description="Perception Analysis",probability_success="60"),
        list_of_opportunity_stage(list_order="7", opportunity_stage_description="Proposal/Price Quote",probability_success="70"),
        list_of_opportunity_stage(list_order="8", opportunity_stage_description="Negotiation/Review",probability_success="80"),
        list_of_opportunity_stage(list_order="9", opportunity_stage_description="Closed Won",probability_success="100",opportunity_closed=True),
        list_of_opportunity_stage(list_order="10", opportunity_stage_description="Closed Lost",probability_success="0",opportunity_closed=True),
    ])

    #List of requirement items status
    list_of_requirement_item_status = apps.get_model("NearBeach","list_of_requirement_item_status")
    list_of_requirement_item_status.objects.using(db_alias).bulk_create([
        list_of_requirement_item_status(requirement_item_status="Draft"),
        list_of_requirement_item_status(requirement_item_status="Review"),
        list_of_requirement_item_status(requirement_item_status="Developing/Working"),
        list_of_requirement_item_status(requirement_item_status="Testing"),
        list_of_requirement_item_status(requirement_item_status="User Acceptance Testing"),
        list_of_requirement_item_status(requirement_item_status="Rework"),
        list_of_requirement_item_status(requirement_item_status="Implemented"),
        list_of_requirement_item_status(requirement_item_status="Finish"),
        list_of_requirement_item_status(requirement_item_status="Not Tested"),
        list_of_requirement_item_status(requirement_item_status="Obsolete"),
    ])

    #List of requirement items type
    list_of_requirement_item_type = apps.get_model("NearBeach","list_of_requirement_item_type")
    list_of_requirement_item_type.objects.using(db_alias).bulk_create([
        list_of_requirement_item_type(requirement_item_type="Informational"),
        list_of_requirement_item_type(requirement_item_type="Feature"),
        list_of_requirement_item_type(requirement_item_type="User Case"),
        list_of_requirement_item_type(requirement_item_type="User Interface"),
        list_of_requirement_item_type(requirement_item_type="Non Functional"),
        list_of_requirement_item_type(requirement_item_type="Constraint"),
        list_of_requirement_item_type(requirement_item_type="System Function"),

    ])


    #List of requirement  status
    list_of_requirement_status = apps.get_model("NearBeach","list_of_requirement_status")
    list_of_requirement_status.objects.using(db_alias).bulk_create([
        list_of_requirement_status(requirement_status="Backlog"),
        list_of_requirement_status(requirement_status="Blocked"),
        list_of_requirement_status(requirement_status="In Progress"),
        list_of_requirement_status(requirement_status="Testing/Review"),
        list_of_requirement_status(requirement_status="Closed",requirement_status_is_closed=True),
    ])

    #List of requirement type
    list_of_requirement_type = apps.get_model("NearBeach","list_of_requirement_type")
    list_of_requirement_type.objects.using(db_alias).bulk_create([
        list_of_requirement_type(requirement_type="Non Specific"),
        list_of_requirement_type(requirement_type="Customer Requirements"),
        list_of_requirement_type(requirement_type="System Requirements"),
    ])



    # List of titles
    list_of_titles = apps.get_model("NearBeach", "list_of_title")
    list_of_titles.objects.using(db_alias).bulk_create([
        list_of_titles(title="Mr"),
        list_of_titles(title="Ms"),
        list_of_titles(title="Mrs"),
        list_of_titles(title="Mx"),
    ])


    # list_of_countries
    list_of_countries = apps.get_model("NearBeach", "list_of_country")
    list_of_countries.objects.using(db_alias).bulk_create([
        list_of_countries(country_id=u"AD", country_name=u"ANDORRA"),
        list_of_countries(country_id=u"AE", country_name=u"UNITED ARAB EMIRATES"),
        list_of_countries(country_id=u"AF", country_name=u"AFGHANISTAN"),
        list_of_countries(country_id=u"AG", country_name=u"ANTIGUA AND BARBUDA"),
        list_of_countries(country_id=u"AI", country_name=u"ANGUILLA"),
        list_of_countries(country_id=u"AL", country_name=u"ALBANIA"),
        list_of_countries(country_id=u"AM", country_name=u"ARMENIA"),
        list_of_countries(country_id=u"AO", country_name=u"ANGOLA"),
        list_of_countries(country_id=u"AQ", country_name=u"ANTARCTICA"),
        list_of_countries(country_id=u"AR", country_name=u"ARGENTINA"),
        list_of_countries(country_id=u"AS", country_name=u"AMERICAN SAMOA"),
        list_of_countries(country_id=u"AT", country_name=u"AUSTRIA"),
        list_of_countries(country_id=u"AU", country_name=u"AUSTRALIA"),
        list_of_countries(country_id=u"AW", country_name=u"ARUBA"),
        list_of_countries(country_id=u"AX", country_name=u"ÅLAND ISLANDS"),
        list_of_countries(country_id=u"AZ", country_name=u"AZERBAIJAN"),
        list_of_countries(country_id=u"BA", country_name=u"BOSNIA AND HERZEGOVINA"),
        list_of_countries(country_id=u"BB", country_name=u"BARBADOS"),
        list_of_countries(country_id=u"BD", country_name=u"BANGLADESH"),
        list_of_countries(country_id=u"BE", country_name=u"BELGIUM"),
        list_of_countries(country_id=u"BF", country_name=u"BURKINA FASO"),
        list_of_countries(country_id=u"BG", country_name=u"BULGARIA"),
        list_of_countries(country_id=u"BH", country_name=u"BAHRAIN"),
        list_of_countries(country_id=u"BI", country_name=u"BURUNDI"),
        list_of_countries(country_id=u"BJ", country_name=u"BENIN"),
        list_of_countries(country_id=u"BL", country_name=u"SAINT BARTHÉLEMY"),
        list_of_countries(country_id=u"BM", country_name=u"BERMUDA"),
        list_of_countries(country_id=u"BN", country_name=u"BRUNEI DARUSSALAM"),
        list_of_countries(country_id=u"BO", country_name=u"BOLIVIA, PLURINATIONAL STATE OF"),
        list_of_countries(country_id=u"BQ", country_name=u"BONAIRE, SINT EUSTATIUS AND SABA"),
        list_of_countries(country_id=u"BR", country_name=u"BRAZIL"),
        list_of_countries(country_id=u"BS", country_name=u"BAHAMAS"),
        list_of_countries(country_id=u"BT", country_name=u"BHUTAN"),
        list_of_countries(country_id=u"BW", country_name=u"BOTSWANA"),
        list_of_countries(country_id=u"BY", country_name=u"BELARUS"),
        list_of_countries(country_id=u"BZ", country_name=u"BELIZE"),
        list_of_countries(country_id=u"CA", country_name=u"CANADA"),
        list_of_countries(country_id=u"CC", country_name=u"COCOS (KEELING) ISLANDS"),
        list_of_countries(country_id=u"CD", country_name=u"CONGO, THE DEMOCRATIC REPUBLIC OF THE"),
        list_of_countries(country_id=u"CF", country_name=u"CENTRAL AFRICAN REPUBLIC"),
        list_of_countries(country_id=u"CG", country_name=u"CONGO"),
        list_of_countries(country_id=u"CH", country_name=u"SWITZERLAND"),
        list_of_countries(country_id=u"CI", country_name=u"CÔTE D'IVOIRE"),
        list_of_countries(country_id=u"CK", country_name=u"COOK ISLANDS"),
        list_of_countries(country_id=u"CL", country_name=u"CHILE"),
        list_of_countries(country_id=u"CM", country_name=u"CAMEROON"),
        list_of_countries(country_id=u"CN", country_name=u"CHINA"),
        list_of_countries(country_id=u"CO", country_name=u"COLOMBIA"),
        list_of_countries(country_id=u"CR", country_name=u"COSTA RICA"),
        list_of_countries(country_id=u"CU", country_name=u"CUBA"),
        list_of_countries(country_id=u"CV", country_name=u"CAPE VERDE"),
        list_of_countries(country_id=u"CW", country_name=u"CURAÇAO"),
        list_of_countries(country_id=u"CX", country_name=u"CHRISTMAS ISLAND"),
        list_of_countries(country_id=u"CY", country_name=u"CYPRUS"),
        list_of_countries(country_id=u"CZ", country_name=u"CZECH REPUBLIC"),
        list_of_countries(country_id=u"DE", country_name=u"GERMANY"),
        list_of_countries(country_id=u"DJ", country_name=u"DJIBOUTI"),
        list_of_countries(country_id=u"DK", country_name=u"DENMARK"),
        list_of_countries(country_id=u"DM", country_name=u"DOMINICA"),
        list_of_countries(country_id=u"DO", country_name=u"DOMINICAN REPUBLIC"),
        list_of_countries(country_id=u"DZ", country_name=u"ALGERIA"),
        list_of_countries(country_id=u"EC", country_name=u"ECUADOR"),
        list_of_countries(country_id=u"EE", country_name=u"ESTONIA"),
        list_of_countries(country_id=u"EG", country_name=u"EGYPT"),
        list_of_countries(country_id=u"EH", country_name=u"WESTERN SAHARA"),
        list_of_countries(country_id=u"ER", country_name=u"ERITREA"),
        list_of_countries(country_id=u"ES", country_name=u"SPAIN"),
        list_of_countries(country_id=u"ET", country_name=u"ETHIOPIA"),
        list_of_countries(country_id=u"FI", country_name=u"FINLAND"),
        list_of_countries(country_id=u"FJ", country_name=u"FIJI"),
        list_of_countries(country_id=u"FK", country_name=u"FALKLAND ISLANDS (MALVINAS)"),
        list_of_countries(country_id=u"FM", country_name=u"MICRONESIA, FEDERATED STATES OF"),
        list_of_countries(country_id=u"FO", country_name=u"FAROE ISLANDS"),
        list_of_countries(country_id=u"FR", country_name=u"FRANCE"),
        list_of_countries(country_id=u"GA", country_name=u"GABON"),
        list_of_countries(country_id=u"GB", country_name=u"UNITED KINGDOM"),
        list_of_countries(country_id=u"GD", country_name=u"GRENADA"),
        list_of_countries(country_id=u"GE", country_name=u"GEORGIA"),
        list_of_countries(country_id=u"GF", country_name=u"FRENCH GUIANA"),
        list_of_countries(country_id=u"GG", country_name=u"GUERNSEY"),
        list_of_countries(country_id=u"GH", country_name=u"GHANA"),
        list_of_countries(country_id=u"GI", country_name=u"GIBRALTAR"),
        list_of_countries(country_id=u"GL", country_name=u"GREENLAND"),
        list_of_countries(country_id=u"GM", country_name=u"GAMBIA"),
        list_of_countries(country_id=u"GN", country_name=u"GUINEA"),
        list_of_countries(country_id=u"GP", country_name=u"GUADELOUPE"),
        list_of_countries(country_id=u"GQ", country_name=u"EQUATORIAL GUINEA"),
        list_of_countries(country_id=u"GR", country_name=u"GREECE"),
        list_of_countries(country_id=u"GS", country_name=u"SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS"),
        list_of_countries(country_id=u"GT", country_name=u"GUATEMALA"),
        list_of_countries(country_id=u"GU", country_name=u"GUAM"),
        list_of_countries(country_id=u"GW", country_name=u"GUINEA-BISSAU"),
        list_of_countries(country_id=u"GY", country_name=u"GUYANA"),
        list_of_countries(country_id=u"HK", country_name=u"HONG KONG "),
        list_of_countries(country_id=u"HM", country_name=u"HEARD ISLAND AND MCDONALD ISLANDS"),
        list_of_countries(country_id=u"HN", country_name=u"HONDURAS"),
        list_of_countries(country_id=u"HR", country_name=u"CROATIA"),
        list_of_countries(country_id=u"HT", country_name=u"HAITI"),
        list_of_countries(country_id=u"HU", country_name=u"HUNGARY"),
        list_of_countries(country_id=u"ID", country_name=u"INDONESIA"),
        list_of_countries(country_id=u"IE", country_name=u"IRELAND"),
        list_of_countries(country_id=u"IL", country_name=u"ISRAEL"),
        list_of_countries(country_id=u"IM", country_name=u"ISLE OF MAN"),
        list_of_countries(country_id=u"IN", country_name=u"INDIA"),
        list_of_countries(country_id=u"IO", country_name=u"BRITISH INDIAN OCEAN TERRITORY"),
        list_of_countries(country_id=u"IQ", country_name=u"IRAQ"),
        list_of_countries(country_id=u"IR", country_name=u"IRAN, ISLAMIC REPUBLIC OF"),
        list_of_countries(country_id=u"IS", country_name=u"ICELAND"),
        list_of_countries(country_id=u"IT", country_name=u"ITALY"),
        list_of_countries(country_id=u"JE", country_name=u"JERSEY"),
        list_of_countries(country_id=u"JM", country_name=u"JAMAICA"),
        list_of_countries(country_id=u"JO", country_name=u"JORDAN"),
        list_of_countries(country_id=u"JP", country_name=u"JAPAN"),
        list_of_countries(country_id=u"KE", country_name=u"KENYA"),
        list_of_countries(country_id=u"KG", country_name=u"KYRGYZSTAN"),
        list_of_countries(country_id=u"KH", country_name=u"CAMBODIA"),
        list_of_countries(country_id=u"KI", country_name=u"KIRIBATI"),
        list_of_countries(country_id=u"KM", country_name=u"COMOROS"),
        list_of_countries(country_id=u"KN", country_name=u"SAINT KITTS AND NEVIS"),
        list_of_countries(country_id=u"KP", country_name=u"KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF"),
        list_of_countries(country_id=u"KR", country_name=u"KOREA, REPUBLIC OF"),
        list_of_countries(country_id=u"KW", country_name=u"KUWAIT"),
        list_of_countries(country_id=u"KY", country_name=u"CAYMAN ISLANDS"),
        list_of_countries(country_id=u"KZ", country_name=u"KAZAKHSTAN"),
        list_of_countries(country_id=u"LA", country_name=u"LAO PEOPLE'S DEMOCRATIC REPUBLIC"),
        list_of_countries(country_id=u"LB", country_name=u"LEBANON"),
        list_of_countries(country_id=u"LC", country_name=u"SAINT LUCIA"),
        list_of_countries(country_id=u"LI", country_name=u"LIECHTENSTEIN"),
        list_of_countries(country_id=u"LK", country_name=u"SRI LANKA"),
        list_of_countries(country_id=u"LR", country_name=u"LIBERIA"),
        list_of_countries(country_id=u"LS", country_name=u"LESOTHO"),
        list_of_countries(country_id=u"LT", country_name=u"LITHUANIA"),
        list_of_countries(country_id=u"LU", country_name=u"LUXEMBOURG"),
        list_of_countries(country_id=u"LV", country_name=u"LATVIA"),
        list_of_countries(country_id=u"LY", country_name=u"LIBYA"),
        list_of_countries(country_id=u"MA", country_name=u"MOROCCO"),
        list_of_countries(country_id=u"MC", country_name=u"MONACO"),
        list_of_countries(country_id=u"MD", country_name=u"MOLDOVA, REPUBLIC OF"),
        list_of_countries(country_id=u"ME", country_name=u"MONTENEGRO"),
        list_of_countries(country_id=u"MF", country_name=u"SAINT MARTIN (FRENCH PART)"),
        list_of_countries(country_id=u"MG", country_name=u"MADAGASCAR"),
        list_of_countries(country_id=u"MH", country_name=u"MARSHALL ISLANDS"),
        list_of_countries(country_id=u"MK", country_name=u"MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF"),
        list_of_countries(country_id=u"ML", country_name=u"MALI"),
        list_of_countries(country_id=u"MM", country_name=u"MYANMAR"),
        list_of_countries(country_id=u"MN", country_name=u"MONGOLIA"),
        list_of_countries(country_id=u"MO", country_name=u"MACAO"),
        list_of_countries(country_id=u"MP", country_name=u"NORTHERN MARIANA ISLANDS"),
        list_of_countries(country_id=u"MQ", country_name=u"MARTINIQUE"),
        list_of_countries(country_id=u"MR", country_name=u"MAURITANIA"),
        list_of_countries(country_id=u"MS", country_name=u"MONTSERRAT"),
        list_of_countries(country_id=u"MT", country_name=u"MALTA"),
        list_of_countries(country_id=u"MU", country_name=u"MAURITIUS"),
        list_of_countries(country_id=u"MV", country_name=u"MALDIVES"),
        list_of_countries(country_id=u"MW", country_name=u"MALAWI"),
        list_of_countries(country_id=u"MX", country_name=u"MEXICO"),
        list_of_countries(country_id=u"MY", country_name=u"MALAYSIA"),
        list_of_countries(country_id=u"MZ", country_name=u"MOZAMBIQUE"),
        list_of_countries(country_id=u"NA", country_name=u"NAMIBIA"),
        list_of_countries(country_id=u"NC", country_name=u"NEW CALEDONIA"),
        list_of_countries(country_id=u"NE", country_name=u"NIGER"),
        list_of_countries(country_id=u"NF", country_name=u"NORFOLK ISLAND"),
        list_of_countries(country_id=u"NG", country_name=u"NIGERIA"),
        list_of_countries(country_id=u"NI", country_name=u"NICARAGUA"),
        list_of_countries(country_id=u"NL", country_name=u"NETHERLANDS"),
        list_of_countries(country_id=u"NO", country_name=u"NORWAY"),
        list_of_countries(country_id=u"NP", country_name=u"NEPAL"),
        list_of_countries(country_id=u"NR", country_name=u"NAURU"),
        list_of_countries(country_id=u"NU", country_name=u"NIUE"),
        list_of_countries(country_id=u"NZ", country_name=u"NEW ZEALAND"),
        list_of_countries(country_id=u"OM", country_name=u"OMAN"),
        list_of_countries(country_id=u"PA", country_name=u"PANAMA"),
        list_of_countries(country_id=u"PE", country_name=u"PERU"),
        list_of_countries(country_id=u"PF", country_name=u"FRENCH POLYNESIA"),
        list_of_countries(country_id=u"PG", country_name=u"PAPUA NEW GUINEA"),
        list_of_countries(country_id=u"PH", country_name=u"PHILIPPINES"),
        list_of_countries(country_id=u"PK", country_name=u"PAKISTAN"),
        list_of_countries(country_id=u"PL", country_name=u"POLAND"),
        list_of_countries(country_id=u"PM", country_name=u"SAINT PIERRE AND MIQUELON"),
        list_of_countries(country_id=u"PN", country_name=u"PITCAIRN"),
        list_of_countries(country_id=u"PR", country_name=u"PUERTO RICO"),
        list_of_countries(country_id=u"PS", country_name=u"PALESTINE, STATE OF"),
        list_of_countries(country_id=u"PT", country_name=u"PORTUGAL"),
        list_of_countries(country_id=u"PW", country_name=u"PALAU"),
        list_of_countries(country_id=u"PY", country_name=u"PARAGUAY"),
        list_of_countries(country_id=u"QA", country_name=u"QATAR"),
        list_of_countries(country_id=u"RE", country_name=u"RÉUNION"),
        list_of_countries(country_id=u"RO", country_name=u"ROMANIA"),
        list_of_countries(country_id=u"RS", country_name=u"SERBIA"),
        list_of_countries(country_id=u"RU", country_name=u"RUSSIAN FEDERATION"),
        list_of_countries(country_id=u"RW", country_name=u"RWANDA"),
        list_of_countries(country_id=u"SA", country_name=u"SAUDI ARABIA"),
        list_of_countries(country_id=u"SB", country_name=u"SOLOMON ISLANDS"),
        list_of_countries(country_id=u"SC", country_name=u"SEYCHELLES"),
        list_of_countries(country_id=u"SD", country_name=u"SUDAN"),
        list_of_countries(country_id=u"SE", country_name=u"SWEDEN"),
        list_of_countries(country_id=u"SG", country_name=u"SINGAPORE"),
        list_of_countries(country_id=u"SH", country_name=u"SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA"),
        list_of_countries(country_id=u"SI", country_name=u"SLOVENIA"),
        list_of_countries(country_id=u"SJ", country_name=u"SVALBARD AND JAN MAYEN"),
        list_of_countries(country_id=u"SK", country_name=u"SLOVAKIA"),
        list_of_countries(country_id=u"SL", country_name=u"SIERRA LEONE"),
        list_of_countries(country_id=u"SM", country_name=u"SAN MARINO"),
        list_of_countries(country_id=u"SN", country_name=u"SENEGAL"),
        list_of_countries(country_id=u"SO", country_name=u"SOMALIA"),
        list_of_countries(country_id=u"SR", country_name=u"SURINAME"),
        list_of_countries(country_id=u"SS", country_name=u"SOUTH SUDAN"),
        list_of_countries(country_id=u"ST", country_name=u"SAO TOME AND PRINCIPE"),
        list_of_countries(country_id=u"SV", country_name=u"EL SALVADOR"),
        list_of_countries(country_id=u"SX", country_name=u"SINT MAARTEN (DUTCH PART)"),
        list_of_countries(country_id=u"SY", country_name=u"SYRIAN ARAB REPUBLIC"),
        list_of_countries(country_id=u"SZ", country_name=u"SWAZILAND"),
        list_of_countries(country_id=u"TC", country_name=u"TURKS AND CAICOS ISLANDS"),
        list_of_countries(country_id=u"TD", country_name=u"CHAD"),
        list_of_countries(country_id=u"TF", country_name=u"FRENCH SOUTHERN TERRITORIES"),
        list_of_countries(country_id=u"TG", country_name=u"TOGO"),
        list_of_countries(country_id=u"TH", country_name=u"THAILAND"),
        list_of_countries(country_id=u"TJ", country_name=u"TAJIKISTAN"),
        list_of_countries(country_id=u"TK", country_name=u"TOKELAU"),
        list_of_countries(country_id=u"TL", country_name=u"TIMOR-LESTE"),
        list_of_countries(country_id=u"TM", country_name=u"TURKMENISTAN"),
        list_of_countries(country_id=u"TN", country_name=u"TUNISIA"),
        list_of_countries(country_id=u"TO", country_name=u"TONGA"),
        list_of_countries(country_id=u"TR", country_name=u"TURKEY"),
        list_of_countries(country_id=u"TT", country_name=u"TRINIDAD AND TOBAGO"),
        list_of_countries(country_id=u"TV", country_name=u"TUVALU"),
        list_of_countries(country_id=u"TW", country_name=u"TAIWAN, PROVINCE OF CHINA"),
        list_of_countries(country_id=u"TZ", country_name=u"TANZANIA, UNITED REPUBLIC OF"),
        list_of_countries(country_id=u"UA", country_name=u"UKRAINE"),
        list_of_countries(country_id=u"UG", country_name=u"UGANDA"),
        list_of_countries(country_id=u"UM", country_name=u"UNITED STATES MINOR OUTLYING ISLANDS"),
        list_of_countries(country_id=u"US", country_name=u"UNITED STATES"),
        list_of_countries(country_id=u"UY", country_name=u"URUGUAY"),
        list_of_countries(country_id=u"UZ", country_name=u"UZBEKISTAN"),
        list_of_countries(country_id=u"VA", country_name=u"HOLY SEE (VATICAN CITY STATE)"),
        list_of_countries(country_id=u"VC", country_name=u"SAINT VINCENT AND THE GRENADINES"),
        list_of_countries(country_id=u"VE", country_name=u"VENEZUELA"),
        list_of_countries(country_id=u"VG", country_name=u"VIRGIN ISLANDS, BRITISH"),
        list_of_countries(country_id=u"VI", country_name=u"VIRGIN ISLANDS, US"),
        list_of_countries(country_id=u"VN", country_name=u"VIET NAM"),
        list_of_countries(country_id=u"VU", country_name=u"VANUATU"),
        list_of_countries(country_id=u"WF", country_name=u"WALLIS AND FUTUNA"),
        list_of_countries(country_id=u"WS", country_name=u"SAMOA"),
        list_of_countries(country_id=u"XZ", country_name=u"INSTALLATIONS IN INTERNATIONAL WATERS"),
        list_of_countries(country_id=u"YE", country_name=u"YEMEN"),
        list_of_countries(country_id=u"YT", country_name=u"MAYOTTE"),
        list_of_countries(country_id=u"ZA", country_name=u"SOUTH AFRICA"),
        list_of_countries(country_id=u"ZM", country_name=u"ZAMBIA"),
        list_of_countries(country_id=u"ZW", country_name=u"ZIMBABWE"),
    ])

    # list_of_countries_states
    list_of_countries_regions = apps.get_model("NearBeach", "list_of_country_region")
    list_of_countries_regions.objects.using(db_alias).bulk_create([
        list_of_countries_regions(country_id=u"AO", region_name=u"Huíla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Lunda Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Lunda Sul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Luanda", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Malange", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Moxico", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Namibe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Uíge", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Zaire", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Salta", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Buenos Aires", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Ciudad Autónoma de Buenos Aires",region_type=u"City"),
        list_of_countries_regions(country_id=u"AR", region_name=u"San Luis", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Entre Ríos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"La Rioja", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Santiago del Estero", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Chaco", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"San Juan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Catamarca", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"La Pampa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Mendoza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Misiones", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Formosa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Neuquén", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Río Negro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Santa Fe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Tucumán", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Chubut", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Tierra del Fuego", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Corrientes", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Córdoba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Jujuy", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AR", region_name=u"Santa Cruz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Burgenland", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Kärnten", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Niederösterreich", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Oberösterreich", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Salzburg", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Steiermark", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Tirol", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Vorarlberg", region_type=u"state"),
        list_of_countries_regions(country_id=u"AT", region_name=u"Wien", region_type=u"state"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Australian Capital Territory",region_type=u"Territory"),
        list_of_countries_regions(country_id=u"AU", region_name=u"New South Wales", region_type=u"State"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Northern Territory", region_type=u"Territory"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Queensland", region_type=u"State"),
        list_of_countries_regions(country_id=u"AU", region_name=u"South Australia", region_type=u"State"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Tasmania", region_type=u"State"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Victoria", region_type=u"State"),
        list_of_countries_regions(country_id=u"AU", region_name=u"Western Australia", region_type=u"State"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Abseron", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Agstafa", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Agcab?di", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Agdam", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Agdas", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Agsu", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Astara", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Baki", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Bab?k", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Balak?n", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"B?rd?", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Beyl?qan", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Bil?suvar", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"C?brayil", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"C?lilabad", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Culfa", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Dask?s?n", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Füzuli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"G?nc?", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"G?d?b?y", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Goranboy", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Göyçay", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Göygöl", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Haciqabul", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Imisli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Ismayilli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"K?lb?c?r", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"K?ng?rli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Kürd?mir", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"L?nk?ran", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Laçin", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"L?nk?ran", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Lerik", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Masalli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Ming?çevir", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Naftalan", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Neftçala", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Naxçivan", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Naxçivan", region_type=u"Autonomous republic"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Oguz", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Ordubad", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Q?b?l?", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Qax", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Qazax", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Quba", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Qubadli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Qobustan", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Qusar", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"S?ki", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Sabirabad", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"S?d?r?k", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Sahbuz", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"S?ki", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Salyan", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"S?rur", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Saatli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Sabran", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Siy?z?n", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"S?mkir", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Sumqayit", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Samaxi", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Samux", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Sirvan", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Susa", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"T?rt?r", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Tovuz", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Ucar", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Xank?ndi", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Xaçmaz", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Xocali", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Xizi", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Xocav?nd", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Yardimli", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Yevlax", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Yevlax", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Z?ngilan", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Zaqatala", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"AZ", region_name=u"Z?rdab", region_type=u"Rayon"),
        list_of_countries_regions(country_id=u"BA", region_name=u"Federacija Bosne i Hercegovine",region_type=u"Entity"),
        list_of_countries_regions(country_id=u"BA", region_name=u"Brcko distrikt",region_type=u"District with special_x000D_ status"),
        list_of_countries_regions(country_id=u"BA", region_name=u"Republika Srpska", region_type=u"Entity"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Christ Church", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Andrew", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint George", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint James", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint John", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Joseph", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Lucy", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Michael", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Peter", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Philip", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BB", region_name=u"Saint Thomas", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Bandarban", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Barguna", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Bogra", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Brahmanbaria", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Bagerhat", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Barisal", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Bhola", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Comilla", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Chandpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Chittagong", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Cox's Bazar", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Chuadanga", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Dhaka", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Dinajpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Faridpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Feni", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Gopalganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Gazipur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Gaibandha", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Habiganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Jamalpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Jessore", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Jhenaidah", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Jaipurhat", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Jhalakati", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Kishoreganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Khulna", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Kurigram", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Khagrachari", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Kushtia", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Lakshmipur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Lalmonirhat", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Manikganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Mymensingh", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Munshiganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Madaripur", region_type=u"District"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Canillo", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Encamp", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"La Massana", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Ordino", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Sant Julià de Lòria", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Andorra la Vella", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AD", region_name=u"Escaldes-Engordany", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AE", region_name=u"'Ajman", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Abu Z¸aby [Abu Dhabi]", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Dubayy [Dubai]", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Al Fujayrah", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Ra’s al Khaymah", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Ash Shariqah [Sharjah]", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AE", region_name=u"Umm al Qaywayn", region_type=u"Emirate"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Balkh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Bamyan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Badghis", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Badakhshan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Baghlan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Daykundi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Farah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Faryab", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Ghazni", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Ghor", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Helmand", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Herat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Jowzjan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Kabul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Kandahar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Kapisa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Kunduz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Khost", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Kuna?", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Laghman", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Logar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Nangarhar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Nimroz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Nuristan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Panjshayr", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Parwan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Paktiya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Paktika", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Samangan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Sar-e Pul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Takhar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Uruzgan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Wardak", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AF", region_name=u"Zabul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint George", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint John", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint Mary", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint Paul", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint Peter", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Saint Philip", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Barbuda", region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"AG", region_name=u"Redonda", region_type=u""),
        list_of_countries_regions(country_id=u"AL", region_name=u"Berat", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Durrës", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Elbasan", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Fier", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Gjirokastër", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Korçë", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Kukës", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Lezhë", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Dibër", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Shkodër", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Tiranë", region_type=u"County"),
        list_of_countries_regions(country_id=u"AL", region_name=u"Vlorë", region_type=u"County"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Aragac?otn", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Ararat", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Armavir", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Erevan", region_type=u"City"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Gegark'unik'", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Kotayk'", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Lo?i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Širak", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Syunik'", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Tavuš", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AM", region_name=u"Vayoc Jor", region_type=u"Region"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Bengo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Benguela", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Bié", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Cabinda", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Kuando Kubango", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Cunene", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Kwanza Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Kwanza Sul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"AO", region_name=u"Huambo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Magura", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Moulvibazar", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Meherpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Narayanganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Netrakona", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Narsingdi", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Narail", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Natore", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Nawabganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Nilphamari", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Noakhali", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Naogaon", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Pabna", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Pirojpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Patuakhali", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Panchagarh", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Rajbari", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Rajshahi", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Rangpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Rangamati", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Sherpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Satkhira", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Sirajganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Sylhet", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Sunamganj", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Shariatpur", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Tangail", region_type=u"District"),
        list_of_countries_regions(country_id=u"BD", region_name=u"Thakurgaon", region_type=u"District"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Bruxelles-Capitale, Région de",region_type=u"Region"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Antwerpen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Vlaams Brabant", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Limburg", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Oost-Vlaanderen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"West-Vlaanderen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Brabant wallon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Hainaut", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Liège", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Luxembourg", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BE", region_name=u"Namur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Balé", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Bam", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Banwa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Bazèga_x000D_ ga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Bougouriba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Boulgou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Boulkiemdé", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Comoé", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Ganzourgou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Gnagna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Gourma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Houet", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Ioba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kadiogo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kénédougou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Komondjari", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kompienga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Koulpélogo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kossi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kouritenga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Kourwéogo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Léraba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Loroum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Mouhoun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Namentenga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Nahouri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Nayala", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Noumbiel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Oubritenga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Oudalan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Passoré", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Poni", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Séno", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Sissili", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Sanmatenga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Sanguié", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Soum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Sourou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Tapoa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Tui", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Yagha", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Yatenga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Ziro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Zondoma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BF", region_name=u"Zoundwéogo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Blagoevgrad", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Burgas", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Varna", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Veliko Tarnovo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Vidin", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Vratsa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Gabrovo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Dobrich", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Kardzhali", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Kjustendil", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Lovech", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Montana", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Pazardzik", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Pernik", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Pleven", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Plovdiv", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Razgrad", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Ruse", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Silistra", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Sliven", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Smolyan", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Sofia (stolitsa)", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Sofia", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Stara Zagora", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Targovishte", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Haskovo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Shumen", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BG", region_name=u"Yambol", region_type=u"Region"),
        list_of_countries_regions(country_id=u"BH", region_name=u"Al ‘Asimah", region_type=u"Governorat"),
        list_of_countries_regions(country_id=u"BH", region_name=u"Al Janubiyah", region_type=u"Governorat"),
        list_of_countries_regions(country_id=u"BH", region_name=u"Al Mu?arraq", region_type=u"Governorat"),
        list_of_countries_regions(country_id=u"BH", region_name=u"Ash Shamaliyah", region_type=u"Governorat"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Bubanza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Bujumbura Rural", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Bujumbura Mairie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Bururi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Cankuzo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Cibitoke", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Gitega", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Kirundo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Karuzi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Kayanza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Makamba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Muramvya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Mwaro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Muyinga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Ngozi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Rumonge", region_type=u"province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Rutana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BI", region_name=u"Ruyigi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Atacora", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Alibori", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Atlantique", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Borgou", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Collines", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Donga", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Couffo", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Littoral", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Mono", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Ouémé", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Plateau", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BJ", region_name=u"Zou", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BN", region_name=u"Belait", region_type=u"District"),
        list_of_countries_regions(country_id=u"BN", region_name=u"Brunei-Muara", region_type=u"District"),
        list_of_countries_regions(country_id=u"BN", region_name=u"Temburong", region_type=u"District"),
        list_of_countries_regions(country_id=u"BN", region_name=u"Tutong", region_type=u"District"),
        list_of_countries_regions(country_id=u"BO", region_name=u"El Beni", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Cochabamba", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Chuquisaca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"La Paz", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Pando", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Oruro", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Potosí", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Santa Cruz", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BO", region_name=u"Tarija", region_type=u"Department"),
        list_of_countries_regions(country_id=u"BQ", region_name=u"Bonaire", region_type=u"Special Municipality"),
        list_of_countries_regions(country_id=u"BQ", region_name=u"Saba", region_type=u"Special Municipality"),
        list_of_countries_regions(country_id=u"BQ", region_name=u"Sint Eustatius",region_type=u"Special Municipality"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Acre", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Alagoas", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Amazonas", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Amapá", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Bahia", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Ceará", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Distrito Federal",region_type=u"Federal district"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Espírito Santo", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Goiás", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Maranhão", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Minas Gerais", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Mato Grosso do Sul", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Mato Grosso", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Pará", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Paraíba", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Pernambuco", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Piauí", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Paraná", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Rio de Janeiro", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Rio Grande do Norte", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Rondônia", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Roraima", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Rio Grande do Sul", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Santa Catarina", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Sergipe", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"São Paulo", region_type=u"State"),
        list_of_countries_regions(country_id=u"BR", region_name=u"Tocantins", region_type=u"State"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Acklins", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Bimini", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Black Point", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Berry Islands", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Central Eleuthera", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Cat Island", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Crooked Island and Long Cay",region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Central Abaco", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Central Andros", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"East Grand Bahama", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Exuma", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"City of Freeport", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Grand Cay", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Harbour Island", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Hope Town", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Inagua", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Long Island", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Mangrove Cay", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Mayaguana", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Moore's Island", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"North Eleuthera", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"North Abaco", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"North Andros", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Rum Cay", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Ragged Island", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"South Andros", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"South Eleuthera", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"South Abaco", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"San Salvador", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"Spanish Wells", region_type=u"District"),
        list_of_countries_regions(country_id=u"BS", region_name=u"West Grand Bahama", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Paro", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Chhukha", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Ha", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Samtse", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Thimphu", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Tsirang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Dagana", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Punakha", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Wangdue Phodrang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Sarpang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Trongsa", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Bumthang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Zhemgang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Trashigang", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Monggar", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Pemagatshel", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Lhuentse", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Samdrup Jongkha", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Gasa", region_type=u"District"),
        list_of_countries_regions(country_id=u"BT", region_name=u"Trashi Yangtse", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Central", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Chobe", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Francistown", region_type=u"City"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Gaborone", region_type=u"City"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Ghanzi", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Jwaneng", region_type=u"Town"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Kgalagadi", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Kgatleng", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Kweneng", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Lobatse", region_type=u"Town"),
        list_of_countries_regions(country_id=u"BW", region_name=u"North East", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"North West", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"South East", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Southern", region_type=u"District"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Selibe Phikwe", region_type=u"Town"),
        list_of_countries_regions(country_id=u"BW", region_name=u"Sowa Town", region_type=u"Town"),
        list_of_countries_regions(country_id=u"BY", region_name=u"Bresckaja voblasc (be) - Brestskaja oblast' (ru)",region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BY", region_name=u"Horad Minsk", region_type=u"City"),
        list_of_countries_regions(country_id=u"BY",region_name=u"Homyel'skaya voblasts' (be) - Gomel'skaya oblast' (ru)",region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BY",region_name=u"Hrodzenskaya voblasts' (be) - Grodnenskaya oblast' (ru)",region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BY",region_name=u"Mahilyowskaya voblasts' (be) - Mogilevskaya oblast' (ru)",region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BY", region_name=u"Minskaya voblasts' (be) - Minskaya oblast' (ru)",
                                  region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BY",
                                  region_name=u"Vitsyebskaya voblasts' (be) - Vitebskaya oblast' (ru)",
                                  region_type=u"Oblast"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Belize", region_type=u"District"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Cayo", region_type=u"District"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Corozal", region_type=u"District"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Orange Walk", region_type=u"District"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Stann Creek", region_type=u"District"),
        list_of_countries_regions(country_id=u"BZ", region_name=u"Toledo", region_type=u"District"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Alberta", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"British Columbia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Manitoba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"New Brunswick", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Newfoundland and Labrador",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Nova Scotia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Northwest Territories", region_type=u"Territory"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Nunavut", region_type=u"Territory"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Ontario", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Prince Edward Island", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Quebec", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Saskatchewan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CA", region_name=u"Yukon", region_type=u"Territory"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Bas-Congo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Bandundu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Équateur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Katanga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Kasai-Oriental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Kinshasa", region_type=u"City"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Kasai-Occidental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Maniema", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Nord-Kivu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Orientale", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CD", region_name=u"Sud-Kivu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Ouham", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Bamingui-Bangoran", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Bangui", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Basse-Kotto", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Haute-Kotto", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Haut-Mbomou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Mambéré-Kadéï", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Gribingui", region_type=u"economic prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Kémo-Gribingui", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Lobaye", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Mbomou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Ombella-Mpoko", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Nana-Mambéré", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Ouham-Pendé", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Sangha", region_type=u"economic prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Ouaka", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CF", region_name=u"Vakaga", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Bouenza", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Pool", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Sangha", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Plateaux", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Cuvette-Ouest", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Pointe-Noire", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Lékoumou", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Kouilou", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Likouala", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Cuvette", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Niari", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CG", region_name=u"Brazzaville", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Aargau (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Appenzell Innerrhoden (de)",
                                  region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Appenzell Ausserrhoden (de)",
                                  region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Bern (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Basel-Landschaft (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Basel-Stadt (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Fribourg (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Genève (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Glarus (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Graubünden (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Jura (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Luzern (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Neuchâtel (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Nidwalden (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Obwalden (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Sankt Gallen (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Schaffhausen (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Solothurn (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Schwyz (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Thurgau (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Ticino (it)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Uri (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Vaud (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Valais (fr)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Zug (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CH", region_name=u"Zürich (de)", region_type=u"Canton"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Abidjan", region_type=u"autonomous district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Bas-Sassandra", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u" Comoé", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Denguélé", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Gôh-Djiboua", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Lacs", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Lagunes", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Montagnes", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Sassandra-Marahoué", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Savanes", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Vallée du Bandama", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Woroba", region_type=u"district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Yamoussoukro", region_type=u"autonomous district"),
        list_of_countries_regions(country_id=u"CI", region_name=u"Zanzan", region_type=u"district"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Aysén", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Antofagasta", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Arica y Parinacota", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Araucanía", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Atacama", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Biobío", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Coquimbo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Libertador General Bernardo O'Higgins",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Los Lagos", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Los Ríos", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Magallanes", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Maule", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Región Metropolitana de Santiago",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Tarapacá", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CL", region_name=u"Valparaíso", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"Adamaoua", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"Centre", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"Far North", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"East", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"Littoral", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"North", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"North-West", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"West", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"South", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CM", region_name=u"South-West", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Beijing", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Tianjin", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Hebei", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Shanxi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Nei Mongol (mn)",
                                  region_type=u"Autonomous Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Liaoning", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Jilin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Heilongjiang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Shanghai", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Jiangsu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Zhejiang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Anhui", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Fujian", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Jiangxi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Shandong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Henan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Hubei", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Hunan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Guangdong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Guangxi", region_type=u"Autonomous Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Hainan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Chongqing", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Sichuan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Guizhou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Yunnan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Xizang", region_type=u"Autonomous Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Shaanxi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Gansu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Qinghai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Ningxia", region_type=u"Autonomous Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Xinjiang", region_type=u"Autonomous Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Taiwan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Xianggang",
                                  region_type=u"Special Administrative Region"),
        list_of_countries_regions(country_id=u"CN", region_name=u"Aomen",
                                  region_type=u"Special Administrative Region"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Amazonas", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Antioquia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Arauca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Atlántico", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Bolívar", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Boyacá", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Caldas", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Caquetá", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Casanare", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Cauca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Cesar", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Chocó", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Córdoba", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Cundinamarca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Distrito Capital de Bogotá",
                                  region_type=u"Capital district"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Guainía", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Guaviare", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Huila", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"La Guajira", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Magdalena", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Meta", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Nariño", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Norte de Santander", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Putumayo", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Quindío", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Risaralda", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Santander", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"San Andrés, Providencia y Santa Catalina",
                                  region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Sucre", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Tolima", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Valle del Cauca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Vaupés", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CO", region_name=u"Vichada", region_type=u"Department"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Alajuela", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Cartago", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Guanacaste", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Heredia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Limón", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"Puntarenas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CR", region_name=u"San José", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Pinar del Río", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"La Habana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Ciudad de La Habana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Matanzas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Villa Clara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Cienfuegos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Sancti Spíritus", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Ciego de Ávila", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Camagüey", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Las Tunas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Holguín", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Granma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Santiago de Cuba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Guantánamo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Artemisa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Mayabeque", region_type=u"Province"),
        list_of_countries_regions(country_id=u"CU", region_name=u"Isla de la Juventud",
                                  region_type=u"Special municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Brava", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Boa Vista", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Santa Catarina", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Santa Catarina do Fogo",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Santa Cruz", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Maio", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Mosteiros", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Paul", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Porto Novo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Praia", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Ribeira Brava", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Ribeira Grande", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Ribeira Grande de Santiago",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Domingos", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Filipe", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Sal", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Miguel", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Lourenço dos Órgãos",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Salvador do Mundo",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"São Vicente", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Tarrafal", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CV", region_name=u"Tarrafal de São Nicolau",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Lefkosia", region_type=u"District"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Lemesos", region_type=u"District"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Larnaka", region_type=u"District"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Ammochostos", region_type=u"District"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Pafos", region_type=u"District"),
        list_of_countries_regions(country_id=u"CY", region_name=u"Keryneia", region_type=u"District"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Jihoceský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Jihomoravský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Karlovarský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Královéhradecký kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Liberecký kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Moravskoslezský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Olomoucký kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Pardubický kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Plzenský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Praha, hlavní mesto", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Stredoceský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Ústecký kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Vysocina", region_type=u"Region"),
        list_of_countries_regions(country_id=u"CZ", region_name=u"Zlínský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Brandenburg", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Berlin", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Baden-Württemberg", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Bayern", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Bremen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Hessen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Hamburg", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Mecklenburg-Vorpommern", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Niedersachsen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Nordrhein-Westfalen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Rheinland-Pfalz", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Schleswig-Holstein", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Saarland", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Sachsen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Sachsen-Anhalt", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DE", region_name=u"Thüringen", region_type=u"Länder"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Arta", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Ali Sabieh", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Dikhil", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Djibouti", region_type=u"City"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Obock", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DJ", region_name=u"Tadjourah", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DK", region_name=u"Nordjylland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DK", region_name=u"Midtjylland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DK", region_name=u"Syddanmark", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DK", region_name=u"Hovedstaden", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DK", region_name=u"Sjælland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Andrew", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint David", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint George", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint John", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Joseph", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Luke", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Mark", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Patrick", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Paul", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DM", region_name=u"Saint Peter", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Distrito Nacional (Santo Domingo)",
                                  region_type=u"District"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Azua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Baoruco", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Barahona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Dajabón", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Duarte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"La Estrelleta [Elías Piña]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"El Seibo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Espaillat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Independencia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"La Altagracia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"La Romana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"La Vega", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"María Trinidad Sánchez", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Monte Cristi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Pedernales", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Peravia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Puerto Plata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Hermanas Mirabal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Samaná", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"San Cristóbal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"San Juan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"San Pedro de Macorís", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Sánchez Ramírez", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Santiago", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Santiago Rodríguez", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Valverde", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Monseñor Nouel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Monte Plata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Hato Mayor", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"San José de Ocoa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Santo Domingo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Cibao Nordeste", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Cibao Noroeste", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Cibao Norte", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Cibao Sur", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"El Valle", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Enriquillo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Higuamo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Ozama", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Valdesia", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DO", region_name=u"Yuma", region_type=u"Region"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Adrar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Chlef", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Laghouat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Oum el Bouaghi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Batna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Béjaïa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Biskra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Béchar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Blida", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Bouira", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tamanrasset", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tébessa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tlemcen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tiaret", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tizi Ouzou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Alger", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Djelfa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Jijel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Sétif", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Saïda", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Skikda", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Sidi Bel Abbès", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Annaba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Guelma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Constantine", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Médéa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Mostaganem", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Msila", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Mascara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Ouargla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Oran", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"El Bayadh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Illizi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Bordj Bou Arréridj", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Boumerdès", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"El Tarf", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tindouf", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tissemsilt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"El Oued", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Khenchela", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Souk Ahras", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Tipaza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Mila", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Aïn Defla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Naama", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Aïn Témouchent", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Ghardaïa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"DZ", region_name=u"Relizane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Azuay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Bolívar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Carchi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Orellana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Esmeraldas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Cañar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Guayas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Chimborazo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Imbabura", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Loja", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Manabí", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Napo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"El Oro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Pichincha", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Los Ríos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Morona-Santiago", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Santo Domingo de los Tsáchilas",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Santa Elena", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Tungurahua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Sucumbíos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Galápagos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Cotopaxi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Pastaza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EC", region_name=u"Zamora-Chinchipe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Harjumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Hiiumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Ida-Virumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Jõgevamaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Järvamaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Läänemaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Lääne-Virumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Põlvamaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Pärnumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Raplamaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Saaremaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Tartumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Valgamaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Viljandimaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EE", region_name=u"Võrumaa", region_type=u"County"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Iskandariyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Aswan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Asyut", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Al Ba?r al A?mar", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Al Bu?ayrah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Bani Suwayf", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Qahirah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Ad Daqahliyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Dumyat", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Fayyum", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Gharbiyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Jizah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Isma 'iliyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Janub Sina'", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Qalyubiyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Kafr ash Shaykh", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Qina", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Al Uqsur", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Minya", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Minufiyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Matruh", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Bur Sa'id", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Suhaj", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Ash Sharqiyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"Shamal Sina'", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"As Suways", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"EG", region_name=u"AI Wadi al Jadid", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"ER", region_name=u"‘Anseba", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ER", region_name=u"Debubawi K’eyyi? Ba?ri", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ER", region_name=u"Debub", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ER", region_name=u"Gash-Barka", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ER", region_name=u"Ma’ikel", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ER", region_name=u"Semienawi K’eyyi? Ba?ri", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Alicante / Alacant", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Albacete", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Almería", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Ávila", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Barcelona  [Barcelona]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Badajoz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Biskaia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Burgos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"A Coruña  [La Coruña]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Cádiz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Cáceres", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Ceuta",
                                  region_type=u"Autonomous city in North Africa"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Córdoba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Ciudad Real", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Castellón / Castelló", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Cuenca", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Las Palmas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Girona  [Gerona]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Granada", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Guadalajara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Huelva", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Huesca", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Jaén", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Lleida  [Lérida]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"León", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"La Rioja", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Lugo  [Lugo]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Madrid", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Málaga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Melilla",
                                  region_type=u"Autonomous city in North Africa"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Murcia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Navarra / Nafarroa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Asturias", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Ourense  [Orense]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Palencia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Balears  [Baleares]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Pontevedra  [Pontevedra]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Cantabria", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Salamanca", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Sevilla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Segovia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Soria", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Gipuzkoa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Tarragona  [Tarragona]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Teruel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Santa Cruz de Tenerife", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Toledo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Valencia / València", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Valladolid", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Álava / Araba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Zaragoza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ES", region_name=u"Zamora", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Adis Abeba", region_type=u"Administration"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Afar", region_type=u""),
        list_of_countries_regions(country_id=u"ET", region_name=u"Amara", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Binshangul Gumuz", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Dire Dawa", region_type=u"Administration"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Gambela Hizboch", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Hareri Hizb", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Oromiya", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"YeDebub Biheroch Bihereseboch na Hizboch",region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Sumale", region_type=u"State"),
        list_of_countries_regions(country_id=u"ET", region_name=u"Tigray", region_type=u"State"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Ahvenanmaan maakunta", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Etelä-Karjala", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Etelä-Pohjanmaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Etelä-Savo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Kainuu", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Kanta-Häme", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Keski-Pohjanmaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Keski-Suomi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Kymenlaakso", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Lappi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Pirkanmaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Pohjanmaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Pohjois-Karjala", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Pohjois-Pohjanmaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Pohjois-Savo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Päijät-Häme", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Satakunta", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Uusimaa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FI", region_name=u"Varsinais-Suomi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Ba", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Bua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Cakaudrove", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Kadavu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Lau", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Lomaiviti", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Macuata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Nadroga and Navosa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Naitasiri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Namosi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Ra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Rewa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Serua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Tailevu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Central", region_type=u"Division"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Eastern", region_type=u"Division"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Northern", region_type=u"Division"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Rotuma", region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"FJ", region_name=u"Western", region_type=u"Division"),
        list_of_countries_regions(country_id=u"FM", region_name=u"Kosrae", region_type=u"State"),
        list_of_countries_regions(country_id=u"FM", region_name=u"Pohnpei", region_type=u"State"),
        list_of_countries_regions(country_id=u"FM", region_name=u"Chuuk", region_type=u"State"),
        list_of_countries_regions(country_id=u"FM", region_name=u"Yap", region_type=u"State"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Ain", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Aisne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Allier", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Alpes-de-Haute-Provence",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Hautes-Alpes",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Alpes-Maritimes",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Ardèche", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Ardennes", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Ariège", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Aube", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Aude", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Aveyron", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Bouches-du-Rhône",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Calvados", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Cantal", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Charente", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Charente-Maritime",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Cher", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Corrèze", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Côte-d'Or",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Côtes-d'Armor",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Creuse", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Dordogne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Doubs", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Drôme", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Eure", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Eure-et-Loir",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Finistère",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Corse-du-Sud",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Corse",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Gard", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Garonne",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Gers", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Gironde", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Hérault", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Ille-et-Vilaine",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Indre", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Indre-et-Loire",region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Isère", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Jura", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Landes", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Loir-et-Cher",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Loire", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Loire",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Loire-Atlantique",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Loiret", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Lot", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Lot-et-Garonne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Lozère", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Maine-et-Loire",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Manche", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Marne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Marne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Mayenne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Meurthe-et-Moselle",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Meuse", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Morbihan", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Moselle", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Nièvre", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Nord", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Oise", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Orne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Pas-de-Calais",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Puy-de-Dôme",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Pyrénées-Atlantiques",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Hautes-Pyrénées",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Pyrénées-Orientales",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Bas-Rhin", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haut-Rhin",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Rhône", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Saône",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Saône-et-Loire",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Sarthe", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Savoie", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Savoie",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Paris", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Seine-Maritime",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Seine-et-Marne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Yvelines", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Deux-Sèvres",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Somme", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Tarn", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Tarn-et-Garonne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Var", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Vaucluse", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Vendée", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Vienne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Haute-Vienne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Vosges", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Yonne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Territoire de Belfort",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Essonne", region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Hauts-de-Seine",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Seine-Saint-Denis",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Val-de-Marne",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"FR", region_name=u"Val-d'Oise",
                                  region_type=u"Metropolitan department"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Estuaire", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Haut-Ogooué", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Moyen-Ogooué", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Ngounié", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Nyanga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Ogooué-Ivindo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Ogooué-Lolo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Ogooué-Maritime", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GA", region_name=u"Woleu-Ntem", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Armagh, Banbridge and Craigavon",
                                  region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Aberdeenshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Aberdeen City", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Argyll and Bute", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Isle of Anglesey [Sir Ynys Môn GB-YNM]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Ards and North Down", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Antrim and Newtownabbey", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Angus", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Armagh", region_type=u"District council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bath and North East Somerset",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Blackburn with Darwen",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bedford", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Barking and Dagenham",
                                  region_type=u"London borough"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Brent", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bexley", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Belfast", region_type=u"District"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bridgend [Pen-y-bont ar Ogwr GB-POG]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Blaenau Gwent", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Birmingham", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Buckinghamshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bournemouth", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Barnet", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Brighton and Hove",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Barnsley", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bolton", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Blackpool", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bracknell Forest",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bradford", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bromley", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bristol, City of",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Bury", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cambridgeshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Caerphilly [Caerffili GB-CAF]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Central Bedfordshire",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Causeway Coast and Glens",
                                  region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Ceredigion [Sir Ceredigion]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cheshire East", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cheshire West and Chester",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Calderdale", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Clackmannanshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cumbria", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Camden", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Carmarthenshire [Sir Gaerfyrddin GB-GFY]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cornwall", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Coventry", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Cardiff [Caerdydd GB-CRD]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Croydon", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Conwy", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Darlington", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Derbyshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Denbighshire [Sir Ddinbych GB-DDB]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Derby", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Devon", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Dumfries and Galloway",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Doncaster", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Dundee City", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Dorset", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u" Derry and Strabane", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Dudley", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Durham", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Ealing", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Ayrshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Edinburgh, City of", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Dunbartonshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Lothian", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Eilean Siar", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Enfield", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Renfrewshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Riding of Yorkshire",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Essex", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"East Sussex", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Falkirk", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Fife", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Flintshire [Sir y Fflint GB-FFL]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u" Fermanagh and Omagh", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Gateshead", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Glasgow City", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Gloucestershire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Greenwich", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Gwynedd", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Halton", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hampshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Havering", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hackney", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Herefordshire", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hillingdon", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Highland", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hammersmith and Fulham",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hounslow", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hartlepool", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Hertfordshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Harrow", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Haringey", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Isles of Scilly",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Isle of Wight", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Islington", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Inverclyde", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Kensington and Chelsea",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Kent", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Kingston upon Hull",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Kirklees", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Kingston upon Thames",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Knowsley", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Lancashire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Lisburn and Castlereagh", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Lambeth", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Leicester", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Leeds", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Leicestershire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Lewisham", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Lincolnshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Liverpool", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"London, City of", region_type=u"City Corporation"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Luton", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Manchester", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Middlesbrough", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Medway", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Mid and East Antrim", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Milton Keynes", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Midlothian", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Monmouthshire [Sir Fynwy GB-FYN]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Merton", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Moray", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Merthyr Tydfil [Merthyr Tudful GB-MTU]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Mid Ulster", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Ayrshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Northumberland", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North East Lincolnshire",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Newcastle upon Tyne", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Norfolk", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Nottingham", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Lanarkshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Lincolnshire",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Newry, Mourne and Down", region_type=u"district"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Somerset", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Northamptonshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB",
                                  region_name=u"Neath Port Talbot [Castell-nedd Port Talbot GB-CTL]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Nottinghamshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Tyneside", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Newham", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Newport [Casnewydd GB-CNW]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"North Yorkshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Oldham", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Orkney Islands", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Oxfordshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Pembrokeshire [Sir Benfro GB-BNF]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Perth and Kinross", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Plymouth", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Poole", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Portsmouth", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Powys", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Peterborough", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Redcar and Cleveland",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Rochdale", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Rhondda, Cynon, Taff [Rhondda, Cynon,Taf]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Redbridge", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Reading", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Renfrewshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Richmond upon Thames",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Rotherham", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Rutland", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Sandwell", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"South Ayrshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Scottish Borders, The",
                                  region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Suffolk", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Sefton", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"South Gloucestershire",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Sheffield", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"St. Helens", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Shropshire", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Stockport", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Salford", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Slough", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"South Lanarkshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Sunderland", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Solihull", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Somerset", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Southend-on-Sea",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Surrey", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Stoke-on-Trent", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Stirling", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Southampton", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Sutton", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Staffordshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Stockton-on-Tees",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"South Tyneside", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Swansea [Abertawe GB-ATA]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Swindon", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Southwark", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Tameside", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Telford and Wrekin",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Thurrock", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Torbay", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Torfaen [Tor-faen]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Trafford", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Tower Hamlets", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Vale of Glamorgan, The [Bro Morgannwg GB-BMG]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Warwickshire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"West Berkshire", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"West Dunbartonshire", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Waltham Forest", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wigan", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wiltshire", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wakefield", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Walsall", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"West Lothian", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wolverhampton", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wandsworth", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Windsor and Maidenhead",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wokingham", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Worcestershire", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wirral", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Warrington", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Wrexham [Wrecsam GB-WRC]",
                                  region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Westminster", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GB", region_name=u"West Sussex", region_type=u"County"),
        list_of_countries_regions(country_id=u"GB", region_name=u"York", region_type=u"Unitary authority"),
        list_of_countries_regions(country_id=u"GB", region_name=u"Shetland Islands", region_type=u"Council area"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint Andrew", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint David", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint George", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint John", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint Mark", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Saint Patrick", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"GD", region_name=u"Southern Grenadine Islands",
                                  region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Abkhazia", region_type=u"Autonomous republic"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Ajaria", region_type=u"Autonomous republic"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Guria", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Imeret'i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Kakhet'i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"K'vemo K'art'li", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Mts'khet'a-Mt'ianet'i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Racha-Lech’khumi-K’vemo Svanet’i",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Samts'khe-Javakhet'i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Shida K'art'li", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"Samegrelo-Zemo Svanet'i", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GE", region_name=u"T'bilisi", region_type=u"City"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Greater Accra", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Ashanti", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Brong-Ahafo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Central", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Eastern", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Northern", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Volta", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Upper East", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Upper West", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GH", region_name=u"Western", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GL", region_name=u"Kommune Kujalleq", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"GL", region_name=u"Qaasuitsup Kommunia", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"GL", region_name=u"Qeqqata Kommunia", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"GL", region_name=u"Kommuneqarfik Sermersooq",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"GM", region_name=u"Banjul", region_type=u"City"),
        list_of_countries_regions(country_id=u"GM", region_name=u"Lower River", region_type=u"Division"),
        list_of_countries_regions(country_id=u"GM", region_name=u"Central River", region_type=u"Division"),
        list_of_countries_regions(country_id=u"GM", region_name=u"North Bank", region_type=u"Division"),
        list_of_countries_regions(country_id=u"GM", region_name=u"Upper River", region_type=u"Division"),
        list_of_countries_regions(country_id=u"GM", region_name=u"Western", region_type=u"Division"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Beyla", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Boffa", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Boké", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Coyah", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Dabola", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Dinguiraye", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Dalaba", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Dubréka", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Faranah", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Forécariah", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Fria", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Gaoual", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Guékédou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Kankan", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Koubia", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Kindia", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Kérouané", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Koundara", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Kouroussa", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Kissidougou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Labé", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Lélouma", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Lola", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Macenta", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Mandiana", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Mali", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Mamou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Nzérékoré", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Pita", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Siguiri", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Télimélé", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Tougué", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GN", region_name=u"Yomou", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Annobón", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Bioko Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Bioko Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Centro Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Kié-Ntem", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Litoral", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GQ", region_name=u"Wele-Nzas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Aitoloakarnanía", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Voiotia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Evvoia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Evrytania", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Fthiotida", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Fokida", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Argolida", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Arkadia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Achaïa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Ileia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Korinthia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Lakonia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Messinia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Zakynthos", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kerkyra", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kefallinía", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Lefkada", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Arta", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Thesprotia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Ioannina", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Preveza", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Karditsa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Larisa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Magnisia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Trikala", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Grevena", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Drama", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Imathia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Thessaloniki", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kavala", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kastoria", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kilkis", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kozani", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Pella", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Pieria", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Serres", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Florina", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Chalkidiki", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Ágion Óros", region_type=u"Self-Governed part"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Evros", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Xanthi", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Rodopi", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Dodekánisa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Kyklades", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Lesvos", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Samos", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Chios", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Irakleio", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Lasithi", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Rethýmnis", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Chania", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GR", region_name=u"Attiki", region_type=u"Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Alta Verapaz", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Baja Verapaz", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Chimaltenango", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Chiquimula", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Escuintla", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Guatemala", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Huehuetenango", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Izabal", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Jalapa", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Jutiapa", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Petén", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"El Progreso", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Quiché", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Quetzaltenango", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Retalhuleu", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Sacatepéquez", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"San Marcos", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Sololá", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Santa Rosa", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Suchitepéquez", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Totonicapán", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GT", region_name=u"Zacapa", region_type=u" Department"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Bafatá", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Bolama", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Biombo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Bissau", region_type=u"Autonomous sector"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Cacheu", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Gabú", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Oio", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Quinara", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GW", region_name=u"Tombali ", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Barima-Waini", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Cuyuni-Mazaruni", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Demerara-Mahaica", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"East Berbice-Corentyne", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Essequibo Islands-West Demerara",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Mahaica-Berbice", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Pomeroon-Supenaam", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Potaro-Siparuni", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Upper Demerara-Berbice", region_type=u"Region"),
        list_of_countries_regions(country_id=u"GY", region_name=u"Upper Takutu-Upper Essequibo",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Atlántida", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Choluteca", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Colón", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Comayagua", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Copán", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Cortés", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"El Paraíso", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Francisco Morazán", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Gracias a Dios", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Islas de la Bahía", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Intibucá", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Lempira", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"La Paz", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Ocotepeque", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Olancho", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Santa Bárbara", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Valle", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HN", region_name=u"Yoro", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Zagrebacka županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Krapinsko-zagorska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Sisacko-moslavacka županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Karlovacka županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Varaždinska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Koprivnicko-križevacka županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Bjelovarsko-bilogorska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Primorsko-goranska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Licko-senjska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Viroviticko-podravska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Požeško-slavonska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Brodsko-posavska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Zadarska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Osjecko-baranjska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Šibensko-kninska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Vukovarsko-srijemska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Splitsko-dalmatinska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Istarska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Dubrovacko-neretvanska županija",
                                  region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Medimurska županija", region_type=u"County"),
        list_of_countries_regions(country_id=u"HR", region_name=u"Grad Zagreb", region_type=u"City"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Artibonite", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Centre", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Grande’Anse", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Nord", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Nord-Est", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Nippes", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Nord-Ouest", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Ouest", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Sud", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HT", region_name=u"Sud-Est", region_type=u"Department"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Baranya", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Békéscsaba", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Békés", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Bács-Kiskun", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Budapest", region_type=u"Capital City"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Borsod-Abaúj-Zemplén", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Csongrád", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Debrecen", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Dunaújváros", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Eger", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Érd", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Fejér", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Gyor-Moson-Sopron", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Gyor", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Hajdú-Bihar", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Heves", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Hódmezovásárhely",
                                  region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Jász-Nagykun-Szolnok", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Komárom-Esztergom", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Kecskemét", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Kaposvár", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Miskolc", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Nagykanizsa", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Nógrád", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Nyíregyháza", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Pest", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Pécs", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Szeged", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Székesfehérvár",
                                  region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Szombathely", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Szolnok", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Sopron", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Somogy", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Szekszárd", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Salgótarján", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Szabolcs-Szatmár-Bereg", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Tatabánya", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Tolna", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Vas", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Veszprém", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Veszprém", region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Zala", region_type=u"County"),
        list_of_countries_regions(country_id=u"HU", region_name=u"Zalaegerszeg",
                                  region_type=u"City of county right"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Aceh", region_type=u"Autononous province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Bali", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Bangka Belitung", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Bengkulu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Banten", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Gorontalo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Jambi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Jawa Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Jawa Timur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Jakarta Raya", region_type=u"Special district"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Jawa Tengah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kalimantan Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kalimantan Timur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kepulauan Riau", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kalimantan Selatan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kalimantan Tengah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Kalimantan Utara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Lampung", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Maluku", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Maluku Utara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Nusa Tenggara Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Nusa Tenggara Timur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Papua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Papua Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Riau", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sulawesi Utara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sumatera Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sulawesi Tenggara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sulawesi Selatan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sulawesi Barat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sumatera Selatan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sulawesi Tengah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Sumatera Utara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ID", region_name=u"Yogyakarta", region_type=u"Special region"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Clare", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Cavan", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Cork", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Carlow", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Dublin", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Donegal", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Galway", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Kildare", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Kilkenny", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Kerry", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Longford", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Louth", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Limerick", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Leitrim", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Laois", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Meath", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Monaghan", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Mayo", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Offaly", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Roscommon", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Sligo", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Tipperary", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Waterford", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Westmeath", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Wicklow", region_type=u"County"),
        list_of_countries_regions(country_id=u"IE", region_name=u"Wexford", region_type=u"County"),
        list_of_countries_regions(country_id=u"IL", region_name=u"HaDarom", region_type=u"District"),
        list_of_countries_regions(country_id=u"IL", region_name=u" H_efa", region_type=u"District"),
        list_of_countries_regions(country_id=u"IL", region_name=u"Yerushalayim", region_type=u"District"),
        list_of_countries_regions(country_id=u"IL", region_name=u"HaMerkaz", region_type=u"District"),
        list_of_countries_regions(country_id=u"IL", region_name=u"Tel-Aviv", region_type=u"District"),
        list_of_countries_regions(country_id=u"IL", region_name=u"HaTsafon", region_type=u"District"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Andaman and Nicobar Islands",
                                  region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Andhra Pradesh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Arunachal Pradesh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Assam", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Bihar", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Chandigarh", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Chhattisgarh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Daman and Diu", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Delhi", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Dadra and Nagar Haveli",
                                  region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Goa", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Gujarat", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Himachal Pradesh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Haryana", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Jharkhand", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Jammu and Kashmir", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Karnataka", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Kerala", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Lakshadweep", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Maharashtra", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Meghalaya", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Manipur", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Madhya Pradesh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Mizoram", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Nagaland", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Odisha", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Punjab", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Puducherry", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Rajasthan", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Sikkim", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Telangana", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Tamil Nadu", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Tripura", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Uttar Pradesh", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"Uttarakhand", region_type=u"State"),
        list_of_countries_regions(country_id=u"IN", region_name=u"West Bengal", region_type=u"State"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"AI Anbar", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Arbil", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Al Basrah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Babil", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Baghdad", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Dahuk", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Diyalá", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Dhi Qar", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Karbala'", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Kirkuk", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Maysan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"AI Muthanná", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"An Najaf", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Ninawá", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Al Qadisiyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Salah ad Din", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"As Sulaymaniyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IQ", region_name=u"Wasit", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"IR", region_name=u"AZarbayjan-e Sharqi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"AZarbayjan-e Gharbi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Ardabil", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Esfahan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Ilam", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Bushehr", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Tehran", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Chahar Ma?al va Bakhtiari",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Khuzestan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Zanjan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Semnan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Sistan va Baluchestan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Fars", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Kerman", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Kordestan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Kermanshah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Kohgiluyeh va Bowyer A?mad",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Gilan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Lorestan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Mazandaran", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Markazi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Hormozgan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Hamadan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Yazd", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Qom", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Golestan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Qazvin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Khorasan-e Jonubi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u" Khorasan-e Ra?avi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Khorasan-e Shomali", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IR", region_name=u"Alborz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Höfuðborgarsvæði utan Reykjavíkur",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Suðurnes", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Vesturland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Vestfirðir", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Norðurland vestra", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Norðurland eystra", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Austurland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IS", region_name=u"Suðurland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Agrigento", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Alessandria", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ancona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Aosta / Aoste (fr)", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ascoli Piceno", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"L'Aquila", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Arezzo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Asti", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Avellino", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Bari", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Bergamo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Biella", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Belluno", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Benevento", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Bologna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Brindisi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Brescia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Barletta-Andria-Trani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Bolzano / Bozen (de)", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Cagliari", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Campobasso", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Caserta", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Chieti", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Carbonia-Iglesias", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Caltanissetta", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Cuneo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Como", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Cremona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Cosenza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Catania", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Catanzaro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Enna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Forlì-Cesena", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ferrara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Foggia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Firenze", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Fermo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Frosinone", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Genova", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Gorizia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Grosseto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Imperia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Isernia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Crotone", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Lecco", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Lecce", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Livorno", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Lodi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Latina", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Lucca", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Monza e Brianza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Macerata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Messina", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Milano", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Mantova", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Modena", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Massa-Carrara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Matera", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Napoli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Novara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Nuoro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ogliastra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Oristano", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Olbia-Tempio", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Palermo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Piacenza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Padova", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pescara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Perugia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pisa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pordenone", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Prato", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Parma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pistoia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pesaro e Urbino", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Pavia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Potenza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ravenna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Reggio Calabria", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Reggio Emilia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Ragusa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Rieti", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Roma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Rimini", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Rovigo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Salerno", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Siena", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Sondrio", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"La Spezia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Siracusa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Sassari", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Savona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Taranto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Teramo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Trento", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Torino", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Trapani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Terni", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Trieste", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Treviso", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Udine", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Varese", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Verbano-Cusio-Ossola", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Vercelli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Venezia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Vicenza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Verona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Medio Campidano", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Viterbo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"IT", region_name=u"Vibo Valentia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Kingston", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Andrew", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Thomas", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Portland", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Mary", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Ann", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Trelawny", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint James", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Hanover", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Westmoreland", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Elizabeth", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Manchester", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Clarendon", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JM", region_name=u"Saint Catherine", region_type=u"Partish"),
        list_of_countries_regions(country_id=u"JO", region_name=u" ‘Ajlun", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Al ‘A¯simah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u" Al ‘Aqabah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"At Tafilah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Az Zarqa’", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Al Balqa’", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Irbid", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Jarash", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"AI Karak", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"AI Mafraq", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Madaba", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JO", region_name=u"Ma‘an", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hokkaidô [Hokkaido]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Aomori", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Iwate", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Miyagi", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Akita", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Yamagata", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hukusima [Fukushima]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Ibaraki", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Totigi [Tochigi]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Gunma", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Saitama", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Tiba [Chiba]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Tôkyô [Tokyo]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Kanagawa", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Niigata", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Toyama", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Isikawa [Ishikawa]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hukui [Fukui]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Yamanasi [Yamanashi]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Nagano", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Gihu [Gifu]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Sizuoka [Shizuoka]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Aiti [Aichi]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Mie", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Siga [Shiga]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hyôgo [Kyoto]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Ôsaka [Osaka]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hyôgo[Hyogo]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Nara", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Wakayama", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Tottori", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Simane [Shimane]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Okayama", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hirosima [Hiroshima]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Yamaguti [Yamaguchi]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Tokusima [Tokushima]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Kagawa", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Ehime", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Kôti [Kochi]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Hukuoka [Fukuoka]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Saga", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Nagasaki", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Kumamoto", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Ôita [Oita]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Miyazaki", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Kagosima [Kagoshima]", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"JP", region_name=u"Okinawa", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Baringo", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Bomet", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Bungoma", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Busia", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Elgeyo/Marakwet", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Embu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Garissa", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Homa Bay", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Isiolo", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kajiado", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kakamega", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kericho", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kiambu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kilifi", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kirinyaga", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kisii", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kisumu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kitui", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Kwale", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Laikipia", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Lamu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Machakos", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Makueni", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Mandera", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Marsabit", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Meru", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Migori", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Mombasa", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Murang'a", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nairobi City", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nakuru", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nandi", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Narok", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nyamira", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nyandarua", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Nyeri", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Samburu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Siaya", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Taita/Taveta", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Tana River", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Tharaka-Nithi", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Trans Nzoia", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Turkana", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Uasin Gishu", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Vihiga", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"Wajir", region_type=u"County"),
        list_of_countries_regions(country_id=u"KE", region_name=u"West Pokot", region_type=u"County"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Batken", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Chü", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Bishkek", region_type=u"City"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Osh", region_type=u"City"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Jalal-Abad", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Naryn", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Osh", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Talas", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KG", region_name=u"Ysyk-Köl", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Banteay Mean Chey [Bântéay Méanchey]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kracheh [Krâchéh]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Mondol Kiri [Môndól Kiri]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Phnom Penh [Phnum Pénh]",
                                  region_type=u"Autonomous municipality"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Preah Vihear [Preah Vihéar]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Prey Veaeng [Prey Vêng]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Pousaat [Pouthisat]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Rotanak Kiri [Rôtânôkiri]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Siem Reab [Siemréab]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Krong Preah Sihanouk [Krong Preah Sihanouk]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Stueng Traeng [Stoeng Trêng]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Baat Dambang [Batdâmbâng]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Svaay Rieng [Svay Rieng]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Taakaev [Takêv]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Otdar Mean Chey [Otdâr Méanchey]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Krong Kaeb [Krong Kêb]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Krong Pailin [Krong Pailin]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Tbong Khmum", region_type=u"province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kampong Chaam [Kâmpóng Cham]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kampong Chhnang [Kâmpóng Chhnang]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kampong Spueu [Kâmpóng Spœ]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kampong Thum [Kâmpóng Thum]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kampot [Kâmpôt]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kandaal [Kândal]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KH", region_name=u"Kaoh Kong [Kaôh Kong]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KI", region_name=u"Gilbert Islands", region_type=u"Group of islands"),
        list_of_countries_regions(country_id=u"KI", region_name=u"Line Islands", region_type=u"Group of islands"),
        list_of_countries_regions(country_id=u"KI", region_name=u"Phoenix Islands", region_type=u"Group of islands"),
        list_of_countries_regions(country_id=u"KM", region_name=u"Anjouan", region_type=u"Island"),
        list_of_countries_regions(country_id=u"KM", region_name=u"Grande Comore", region_type=u"Island"),
        list_of_countries_regions(country_id=u"KM", region_name=u"Mohéli", region_type=u"Island"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Christ Church Nichola Town",
                                  region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Anne Sandy Point", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint George Basseterre", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint George Gingerland", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint James Windward", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint John Capisterre", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint John Figtree", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Mary Cayon", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Paul Capisterre", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Paul Charlestown", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Peter Basseterre", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Thomas Lowland", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Saint Thomas Middle Island",
                                  region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KN", region_name=u"Trinity Palmetto Point", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Phyeongyang", region_type=u"Capital City"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Phyeongannamto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Phyeonganpukto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Jakangto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Hwanghainamto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Hwanghaipukto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Kangweonto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Hamkyeongnamto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Hamkyeongpukto", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Yanggang-do", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KP", region_name=u"Nason", region_type=u"Special City"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Seoul-teukbyeolsi [Seoul]",
                                  region_type=u"Special city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Busan Gwang'yeogsi [Pusan-Kwangyokshi]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Daegu Gwang'yeogsi [Taegu-Kwangyokshi]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Incheon Gwang'yeogsi [Incheon]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Gwangju Gwang'yeogsi [Kwangju-Kwangyokshi]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Daejeon Gwang'yeogsi [Taejon-Kwangyokshi]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Ulsan Gwang'yeogsi [Ulsan-Kwangyokshi]",
                                  region_type=u"Metropolitan city"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Gyeonggido [Kyonggi-do]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Gang'weondo [Kang-won-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Chungcheongbugdo [Ch'ungch'ongbuk-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Chungcheongnamdo [Ch'ungch'ongnam-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Jeonrabugdo [Chollabuk-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Jeonranamdo [Chollanam-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Gyeongsangbugdo [Kyongsangbuk-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Gyeongsangnamdo [Kyongsangnam-do]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Jeju-teukbyeoljachido [Jeju]",
                                  region_type=u"Special self-governing province"),
        list_of_countries_regions(country_id=u"KR", region_name=u"Sejong",
                                  region_type=u"Special self-governing city"),
        list_of_countries_regions(country_id=u"KW", region_name=u"Al A?madi", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KW", region_name=u"Al Farwaniyah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KW", region_name=u"?awalli", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KW", region_name=u"Al Jahra’", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KW", region_name=u" Al ‘Asimah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KW", region_name=u"Mubarak al Kabir", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Aqmola oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Aqtöbe oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Almaty", region_type=u"City"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Almaty oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Astana", region_type=u"City"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Atyrau oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Qaraghandy oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Qostanay oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Qyzylorda oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Mangghystau oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Pavlodar oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Soltüstik Qazaqstan oblysy",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Shyghys Qazaqstan oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Ongtüstik Qazaqstan oblysy",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Batys Qazaqstan oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"KZ", region_name=u"Zhambyl oblysy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Attapu [Attopeu]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Bokèo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Bolikhamxai [Borikhane]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Champasak [Champassak]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Houaphan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Khammouan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Louang Namtha", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Louangphabang [Louang Prabang)",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Oudômxai [Oudomsai]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Phôngsali [Phong Saly]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Salavan [Saravane]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Savannakhét", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Vientiane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Vientiane", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Xaignabouli [Sayaboury]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Xékong [Sékong]", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Xiangkhouang [Xieng Khouang]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"LA", region_name=u"Xaisômboun", region_type=u"province"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Aakkâr", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Liban-Nord", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Beyrouth", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Baalbek-Hermel", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"El Béqaa", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Liban-Sud", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Mont-Liban", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LB", region_name=u"Nabatîyé", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Anse la Raye", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Castries", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Choiseul", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Dennery", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Gros Islet", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Laborie", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Micoud", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Soufrière", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Vieux Fort", region_type=u"District"),
        list_of_countries_regions(country_id=u"LC", region_name=u"Canaries", region_type=u"District"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Balzers", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Eschen", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Gamprin", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Mauren", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Planken", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Ruggell", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Schaan", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Schellenberg", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Triesen", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Triesenberg", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LI", region_name=u"Vaduz", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Basnahira pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Colombo", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Gampaha", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Kalutara", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Madhyama pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Kandy", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Matale", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Nuwara Eliya", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Daku?u pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Galle", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Matara", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Hambantota", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Uturu pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Jaffna", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Kilinochchi", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Mannar", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Vavuniya", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Mullaittivu", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Næ?genahira pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Batticaloa", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Ampara", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Trincomalee", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Vayamba pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Kurunegala", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Puttalam", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Uturumæ?da pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Anuradhapura", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Polonnaruwa", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Uva pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Badulla", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Monaragala", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Sabaragamuva pa?ata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Ratnapura", region_type=u"District"),
        list_of_countries_regions(country_id=u"LK", region_name=u"Kegalla", region_type=u"District"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Bong", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Bomi", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Grand Cape Mount", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Grand Bassa", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Grand Gedeh", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Grand Kru", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Gbarpolu", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Lofa", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Margibi", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Montserrado", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Maryland", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Nimba", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"River Gee", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u" River Cess", region_type=u"County"),
        list_of_countries_regions(country_id=u"LR", region_name=u"Sinoe", region_type=u"County"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Maseru", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Butha-Buthe", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Leribe", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Berea", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Mafeteng", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Mohale's Hoek", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Quthing", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Qacha's Nek", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Mokhotlong", region_type=u"District"),
        list_of_countries_regions(country_id=u"LS", region_name=u"Thaba-Tseka", region_type=u"District"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Akmene", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Alytaus miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Alytus", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Anykšciai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Birštono", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Biržai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Druskininkai", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Elektrénai", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Ignalina", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Jonava", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Joniškis", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Jurbarkas", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kaišiadorys",
                                  region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kalvarijos", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kauno miestas", region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kaunas", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kazlu Rudos", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kedainiai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kelme", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Klaipedos miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Klaipeda", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kretinga", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kupiškis", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Lazdijai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Marijampole",
                                  region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Mažeikiai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Moletai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Neringa", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Pagégiai", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Pakruojis", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Palangos miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Panevežio miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Panevežys", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Pasvalys", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Plunge", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Prienai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Radviliškis",
                                  region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Raseiniai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Rietavo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Rokiškis", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šakiai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šalcininkai",
                                  region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šiauliu miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šiauliai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šilale", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šilute", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Širvintos", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Skuodas", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Švencionys", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Taurage", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Telšiai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Trakai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Ukmerge", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Utena", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Varena", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Vilkaviškis",
                                  region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Vilniaus miestas",
                                  region_type=u"City municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Vilnius", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Visaginas", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Zarasai", region_type=u"District municipality"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Alytaus Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Klaipedos apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Kauno Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Marijampoles apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Panevežio apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Šiauliu Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Taurages apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Telšiu Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Utenos Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LT", region_name=u"Vilniaus Apskritis", region_type=u"County"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Capellen", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Clervaux", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Diekirch", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Echternach", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Esch-sur-Alzette", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Gréivemaacher", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Luxembourg", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Mersch", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Redange", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Remich", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Vianden", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LU", region_name=u"Wiltz", region_type=u"canton"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Aglonas novads (Aglona)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Aizkraukles novads (Aizkraukle)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Aizputes novads (Aizpute)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Aknistes novads (Akniste)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Alojas novads (Aloja)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Alsungas novads (Alsunga)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Aluksnes novads (Aluksne)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Amatas novads (Amata)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Apes novads (Ape)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Auces novads (Auce)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Adažu novads (Adaži)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Babites novads (Babite)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Baldones novads (Baldone)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Baltinavas novads (Baltinava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Balvu novads (Balvi)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Bauskas novads (Bauska)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Beverinas novads (Beverina)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Brocenu novads (Broceni)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Burtnieku novads (Burtnieki)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Carnikavas novads (Carnikava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Cesvaines novads (Cesvaine)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Cesu novads (Cesis)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ciblas novads (Cibla)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Dagdas novads (Dagda)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Daugavpils novads (Daugavpils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Dobeles novads (Dobele)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Dundagas novads (Dundaga)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Durbes novads (Durbe)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Engures novads (Engure)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Erglu novads (Ergli)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Garkalnes novads (Garkalne)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Grobinas novads (Grobina)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Gulbenes novads (Gulbene)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Iecavas novads (Iecava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ikškiles novads (Ikškile)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ilukstes novads (Ilukste)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Incukalna novads (Incukalns)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jaunjelgavas novads_x000D_ (Jaunjelgava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jaunpiebalgas novads_x000D_ (Jaunpiebalga)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jaunpils novads (Jaunpils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jelgavas novads (Jelgava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jekabpils novads (Jekabpils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kandavas novads (Kandava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Karsavas novads (Karsava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kocenu novads (Koceni)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kokneses novads (Koknese)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kraslavas novads (Kraslava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Krimuldas novads (Krimulda)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Krustpils novads (Krustpils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kuldigas novads (Kuldiga)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Keguma novads (Kegums)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Kekavas novads (Kekava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Lielvardes novads (Lielvarde)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Limbažu novads (Limbaži)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ligatnes novads (Ligatne)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Livanu novads (Livani)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Lubanas novads (Lubana)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ludzas novads (Ludza)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Madonas novads (Madona)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Mazsalacas novads (Mazsalaca)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Malpils novads (Malpils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Marupes novads (Marupe)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Mersraga novads (Mersrags)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Naukšenu novads (Naukšeni)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Neretas novads (Nereta)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Nicas novads (Nica)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ogres novads (Ogre)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Olaines novads (Olaine)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ozolnieku novads (Ozolnieki)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Pargaujas novads (Pargauja)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Pavilostas novads (Pavilosta)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Plavinu novads (Plavinas)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Preilu novads (Preili)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Priekules novads (Priekule)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Priekulu novads (Priekuli)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Raunas novads (Rauna)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rezeknes novads (Rezekne)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Riebinu novads (Riebini)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rojas novads (Roja)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ropažu novads (Ropaži)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rucavas novads (Rucava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rugaju novads (Rugaji)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rundales novads (Rundale)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rujienas novads (Rujiena)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Salas novads (Sala)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Salacgrivas novads (Salacgriva)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Salaspils novads (Salaspils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Saldus novads (Saldus)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Saulkrastu novads (Saulkrasti)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Sejas novads (Seja)", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Siguldas novads (Sigulda)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Skriveru novads (Skriveri)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Skrundas novads (Skrunda)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Smiltenes novads (Smiltene)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Stopinu novads (Stopini)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Strencu novads (Strenci)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Talsu novads (Talsi)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Tervetes novads (Tervete)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Tukuma novads (Tukums)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Vainodes novads (Vainode)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Valkas novads (Valka)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Varaklanu novads (Varaklani)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Varkavas novads (Varkava)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Vecpiebalgas novads_x000D_ (Vecpiebalga)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Vecumnieku novads (Vecumnieki)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ventspils novads (Ventspils)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Viesites novads (Viesite)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Vilakas novads (Vilaka)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Vilanu novads (Vilani)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Zilupes novads (Zilupe)",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Daugavpils", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jelgava", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jekabpils", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Jurmala", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Liepaja", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Rezekne", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Riga", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Ventspils", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LV", region_name=u"Valmiera", region_type=u"Republican city"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Banghazi", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Butnan", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Darnah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Ghat", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Jabal al Akh?ar", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Jabal al Gharbi", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Jafarah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Jufrah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Kufrah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Marqab", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Misratah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Marj", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Murzuq", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Nalut", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"An Nuqat al Khams", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Sabha", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Surt", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Tarabulus", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Al Wa?at", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Wadi al Hayat", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Wadi ash Shati?", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"LY", region_name=u"Az Zawiyah", region_type=u"Popularate"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tanger-Tétouan", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Gharb-Chrarda-Beni Hssen",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Taza-Al Hoceima-Taounate",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"L'Oriental", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Fès-Boulemane", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Meknès-Tafilalet", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Rabat-Salé-Zemmour-Zaer",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Grand Casablanca", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Chaouia-Ouardigha",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Doukhala-Abda", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Marrakech-Tensift-Al Haouz",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tadla-Azilal", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Sous-Massa-Draa", region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Guelmim-Es Semara",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Laâyoune-Boujdour-Sakia el Hamra",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Oued ed Dahab-Lagouira",
                                  region_type=u"Economic Region"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Agadir-Ida-Outanane", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Aousserd", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Assa-Zag", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Azilal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Beni Mellal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Berkane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Ben Slimane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Boujdour (EH)", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Boulemane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Casablanca [Dar el Beïda]*",
                                  region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Chefchaouene", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Chichaoua", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Chtouka-Ait Baha", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Errachidia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Essaouira", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Es Smara (EH)", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Fahs-Beni Makada", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Fès-Dar-Dbibegh", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Figuig", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Guelmim", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"El Hajeb", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Al Haouz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Al Hoceïma", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Ifrane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Inezgane-Ait Melloul", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"El Jadida", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Jrada", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Kénitra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Kelaat Sraghna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Khemisset", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Khenifra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Khouribga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Laâyoune", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Larache", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Médiouna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Meknès*", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Marrakech-Medina", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Marrakech-Menara", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Mohammadia", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Moulay Yacoub", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Nador", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Nouaceur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Ouarzazate", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Oued ed Dahab (EH)", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Oujda-Angad", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Rabat", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Safi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Salé", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Sefrou", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Settat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Sidi Kacem", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Skhirate-Témara", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Sidi Youssef Ben Ali", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Taourirt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Taounate", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Taroudannt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tata", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Taza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tétouan*", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tiznit", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tanger-Assilah", region_type=u"Prefecture"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Tan-Tan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MA", region_name=u"Zagora", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MC", region_name=u"La Colle", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"La Condamine", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Fontvieille", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"La Gare", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Jardin Exotique", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Larvotto", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Malbousquet", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Monte-Carlo", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Moneghetti", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Monaco-Ville", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Moulins", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Port-Hercule", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Sainte-Dévote", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"La Source", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Spélugues", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Saint-Roman", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MC", region_name=u"Vallon de la Rousse", region_type=u"Quarter"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Anenii Noi", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Balti", region_type=u"City"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Bender [Tighina]", region_type=u"City"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Briceni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Basarabeasca", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Cahul", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Calarasi", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Cimislia", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Criuleni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Causeni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Cantemir", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Chisinau", region_type=u"City"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Donduseni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Drochia", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Dubasari", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Edinet", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Falesti", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Floresti", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD",
                                  region_name=u"Gagauzia, Unitatea teritoriala_x000D_ autonoma (UTAG)",
                                  region_type=u"Autonomous territory unit"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Glodeni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Hîncesti", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Ialoveni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Leova", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Nisporeni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Ocniþa", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Orhei", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Rezina", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Rîscani", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Soldanesti", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Sîngerei", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Stînga Nistrului, unitatea teritoriala din",
                                  region_type=u"Territorial unit"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Soroca", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Straseni", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Stefan Voda", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Taraclia", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Telenesti", region_type=u"District"),
        list_of_countries_regions(country_id=u"MD", region_name=u"Ungheni", region_type=u"District"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Andrijevica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Bar", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Berane", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Bijelo Polje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Budva", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Cetinje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Danilovgrad", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Herceg-Novi", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Kolašin", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Kotor", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Mojkovac", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Nikšic´", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Plav", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Pljevlja", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Plužine", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Podgorica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Rožaje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Šavnik", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Tivat", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Ulcinj", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Žabljak", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Gusinje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"ME", region_name=u"Petnjica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Toamasina", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Antsiranana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Fianarantsoa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Mahajanga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Antananarivo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MG", region_name=u"Toliara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ailuk", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ailinglapalap", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Arno", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Aur", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ebon", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Enewetak and Ujelang",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Jabat", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Jaluit", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Bikini and Kili", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Kwajalein", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ralik chain", region_type=u"Chains (of islands)"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Lae", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Lib", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Likiep", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Majuro", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Maloelap", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Mejit", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Mili", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Namdrik", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Namu", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Rongelap", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ratak chain", region_type=u"Chains (of islands)"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Ujae", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Utrik", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Wotho", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MH", region_name=u"Wotje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Aracinovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Berovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Bitola", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Bogdanci", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Bogovinje", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Bosilovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Brvenica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Valandovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Vasilevo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Vevcani", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Veles", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Vinica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Vrapcište", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Gevgelija", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Gostivar", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Gradsko", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Debar", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Debarca", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Delcevo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Demir Kapija", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Demir Hisar", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Dojran", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Dolneni", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Želino", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Zelenikovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Zrnovci", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Ilinden", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Jegunovce", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kavadarci", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Karbinci", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kicevo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Konce", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kocani", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kratovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kriva Palanka", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Krivogaštani", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kruševo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Kumanovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Lipkovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Lozovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Mavrovo-i-Rostuša", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Makedonska Kamenica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Makedonski Brod", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Mogila", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Negotino", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Novaci", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Novo Selo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Ohrid", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Petrovec", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Pehcevo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Plasnica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Prilep", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Probištip", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Radoviš", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Rankovce", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Resen", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Rosoman", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Sveti Nikole", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Sopište", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Staro Nagoricane", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Struga", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Strumica", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Studenicani", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Tearce", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Tetovo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Centar Župa", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Caška", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Cešinovo-Obleševo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Cucer Sandevo", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Štip", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"MK", region_name=u"Skopje", region_type=u"municipality"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Kayes", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Koulikoro", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Sikasso", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Ségou", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Mopti", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Tombouctou", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Gao", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Kidal", region_type=u"Region"),
        list_of_countries_regions(country_id=u"ML", region_name=u"Bamako", region_type=u"District"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Sagaing", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Bago", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Magway", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Mandalay", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Taninthayi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Yangon", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Ayeyawady", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Kachin", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Kayah", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Kayin", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Chin", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Mon", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Rakhine", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Shan", region_type=u"State"),
        list_of_countries_regions(country_id=u"MM", region_name=u"Nay Pyi Taw", region_type=u"Union territory"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Orhon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Darhan uul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Hentiy", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Hövagöl", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Hovd", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Uvs", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Töv", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Selenge", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Sühbaatar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Ömnögovi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Övörhangay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Dzavhan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Dundgovi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Dornod", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Dornogovi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Govi-Sümber", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Govi-Altay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Bulgan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Bayanhongor", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Bayan-Ölgiy", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Arhangay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MN", region_name=u"Ulaanbaatar", region_type=u"Capital city"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Hodh ech Chargui", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Hodh el Gharbi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Assaba", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Gorgol", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Brakna", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Trarza", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Adrar", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Dakhlet Nouâdhibou", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Tagant", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Guidimaka", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Tiris Zemmour", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Inchiri", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Nouakchott Ouest", region_type=u"region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Nouakchott Nord", region_type=u"region"),
        list_of_countries_regions(country_id=u"MR", region_name=u"Nouakchott Sud", region_type=u"region"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Attard", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Balzan", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Birgu", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Birkirkara", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Birzebbuga", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Bormla", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Dingli", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Fgura", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Floriana", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Fontana", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Gudja", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Gzira", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Ghajnsielem", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Gharb", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Gharghur", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Ghasri", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Ghaxaq", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Hamrun", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Iklin", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Isla", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Kalkara", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Kercem", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Kirkop", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Lija", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Luqa", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Marsa", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Marsaskala", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Marsaxlokk", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mdina", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mellieha", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mgarr", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mosta", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mqabba", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Msida", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Mtarfa", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Munxar", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Nadur", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Naxxar", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Paola", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Pembroke", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Pietà", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Qala", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Qormi", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Qrendi", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Rabat Gozo", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Rabat Malta", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Safi", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Saint Julian's", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Saint John", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Saint Lawrence", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Saint Paul's Bay", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Sannat", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Saint Lucia's", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Santa Venera", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Siggiewi", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Sliema", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Swieqi", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Ta' Xbiex", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Tarxien", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Valletta", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Xaghra", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Xewkija", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Xghajra", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Zabbar", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Zebbug Gozo", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Zebbug Malta", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Zejtun", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MT", region_name=u"Zurrieq", region_type=u"Local council"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Agalega Islands", region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Black River", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Beau Bassin-Rose Hill", region_type=u"City"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Cargados Carajos Shoals [Saint Brandon Islands]",
                                  region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Curepipe", region_type=u"City"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Flacq", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Grand Port", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Moka", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Pamplemousses", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Port Louis", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Port Louis", region_type=u"City"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Plaines wilhems", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Quatre Bornes", region_type=u"City"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Rodrigues Island", region_type=u"Dependency"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Rivière du Rempart", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Savanne", region_type=u"District"),
        list_of_countries_regions(country_id=u"MU", region_name=u"Vacoas-Phoenix", region_type=u"City"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Alifu Dhaalu",
                                  region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Seenu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Alifu Alifu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Lhaviyani", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Vaavu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Laamu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Haa Alif", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Thaa", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Meemu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Raa", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Faafu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Dhaalu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Baa", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Haa Dhaalu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Shaviyani", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Noonu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Kaafu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Gaafu Alifu", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Gaafu Dhaalu",
                                  region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Gnaviyani", region_type=u"Administrative atoll"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Medhu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Male", region_type=u"Capital"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Medhu-Uthuru", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Uthuru", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Medhu-Dhekunu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Dhekunu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Mathi-Uthuru", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MV", region_name=u"Mathi-Dhekunu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Balaka", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Blantyre", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Central", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Chikwawa", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Chiradzulu", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Chitipa", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Dedza", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Dowa", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Karonga", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Kasungu", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Lilongwe", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Likoma", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Mchinji", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Mangochi", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Machinga", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Mulanje", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Mwanza", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Mzimba", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Northern", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Nkhata Bay", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Neno", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Ntchisi", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Nkhotakota", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Nsanje", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Ntcheu", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Phalombe", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Rumphi", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Southern", region_type=u"Region"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Salima", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Thyolo", region_type=u"District"),
        list_of_countries_regions(country_id=u"MW", region_name=u"Zomba", region_type=u"District"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Aguascalientes", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Baja California", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Baja California Sur", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Campeche", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Chihuahua", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Chiapas", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Coahuila", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Colima", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Distrito Federal",
                                  region_type=u"Federal District"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Durango", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Guerrero", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Guanajuato", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Hidalgo", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Jalisco", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"México", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Michoacán", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Morelos", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Nayarit", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Nuevo León", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Oaxaca", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Puebla", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Querétaro", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Quintana Roo", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Sinaloa", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"San Luis Potosí", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Sonora", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Tabasco", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Tamaulipas", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Tlaxcala", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Veracruz", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Yucatán", region_type=u"State"),
        list_of_countries_regions(country_id=u"MX", region_name=u"Zacatecas", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Johor", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Kedah", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Kelantan", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Melaka", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Negeri Sembilan", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Pahang", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Pulau Pinang", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Perak", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Perlis", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Selangor", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Terengganu", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Sabah", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Sarawak", region_type=u"State"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Wilayah Persekutuan Kuala Lumpur",
                                  region_type=u"Federal territory"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Wilayah Persekutuan Labuan",
                                  region_type=u"Federal territory"),
        list_of_countries_regions(country_id=u"MY", region_name=u"Wilayah Persekutuan Putrajaya",
                                  region_type=u"Federal territory"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Niaosa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Manica", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Gaza", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Inhambane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Maputo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Maputo", region_type=u"City"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Nampula", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Cabo Delgado", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Zambézia", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Sofala", region_type=u"Province"),
        list_of_countries_regions(country_id=u"MZ", region_name=u"Tete", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Zambezi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Erongo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Hardap", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Karas", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Kavango East", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Khomas", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Kunene", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Kavango West", region_type=u""),
        list_of_countries_regions(country_id=u"NA", region_name=u"Otjozondjupa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Omaheke", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Oshana", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Omusati", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Oshikoto", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NA", region_name=u"Ohangwena", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Agadez", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Diffa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Dosso", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Maradi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Tahoua", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Tillabéri", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Zinder", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NE", region_name=u"Niamey", region_type=u"Urban community"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Abia", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Adamawa", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Akwa Ibom", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Anambra", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Bauchi", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Benue", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Borno", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Bayelsa", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Cross River", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Delta", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Ebonyi", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Edo", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Ekiti", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Enugu", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Abuja Capital Territory",
                                  region_type=u"Capital territory"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Gombe", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Imo", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Jigawa", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Kaduna", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Kebbi", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Kano", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Kogi", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Katsina", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Kwara", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Lagos", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Nasarawa", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Niger", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Ogun", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Ondo", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Osun", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Oyo", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Plateau", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Rivers", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Sokoto", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Taraba", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Yobe", region_type=u"State"),
        list_of_countries_regions(country_id=u"NG", region_name=u"Zamfara", region_type=u"State"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Atlántico Norte",
                                  region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Atlántico Sur", region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Boaco", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Carazo", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Chinandega", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Chontales", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Estelí", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Granada", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Jinotega", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"León", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Madriz", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Managua", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Masaya", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Matagalpa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Nueva Segovia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Rivas", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NI", region_name=u"Río San Juan", region_type=u"Department"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Drenthe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Flevoland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Fryslân", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Gelderland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Groningen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Limburg", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Noord-Brabant", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Noord-Holland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Overijssel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Utrecht", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Zeeland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NL", region_name=u"Zuid-Holland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Østfold", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Akershus", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Oslo", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Hedmark", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Oppland", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Buskerud", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Vestfold", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Telemark", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Aust-Agder", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Vest-Agder", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Rogaland", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Hordaland", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Sogn og Fjordane", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Møre og Romsdal", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Sør-Trøndelag", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Nord-Trøndelag", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Nordland", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Troms", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO", region_name=u"Finnmark", region_type=u"County"),
        list_of_countries_regions(country_id=u"NO",
                                  region_name=u"Svalbard (Arctic Region) (See_x000D_ also country code SJ)",
                                  region_type=u"Arctic region"),
        list_of_countries_regions(country_id=u"NO",
                                  region_name=u"Jan Mayen (Arctic Region) (See_x000D_ also country code SJ)",
                                  region_type=u"Arctic region"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Bagmati", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Bheri", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Dhawalagiri", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Gandaki", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Janakpur", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Karnali", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Kosi [Koshi]", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Lumbini", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Mahakali", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Mechi", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Narayani", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Rapti", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Sagarmatha", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NP", region_name=u"Seti", region_type=u"Zone"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Aiwo", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Anabar", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Anetan", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Anibare", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Baiti", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Boe", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Buada", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Denigomodu", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Ewa", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Ijuw", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Meneng", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Nibok", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Uaboe", region_type=u"District"),
        list_of_countries_regions(country_id=u"NR", region_name=u"Yaren", region_type=u"District"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Auckland", region_type=u"region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Bay of Plenty", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Canterbury", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Chatham Islands Territory",
                                  region_type=u"Special Island Authorithy"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Gisborne", region_type=u"region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Hawkes's Bay", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Marlborough", region_type=u"region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Manawatu-Wanganui", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u" Nelson", region_type=u"region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Northland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Otago", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Southland", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u" Tasman", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Taranaki", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Wellington", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"Waikato", region_type=u"Region"),
        list_of_countries_regions(country_id=u"NZ", region_name=u"West Coast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Janub al Batinah", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Shamal al Batinah", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Al Buraymi", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Ad Dakhiliyah", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Masqat", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Musandam", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Janub ash Sharqiyah", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Shamal ash Sharqiyah", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"AI Wusta", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Az Zahirah", region_type=u"Region"),
        list_of_countries_regions(country_id=u"OM", region_name=u"Z¸ufar", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Bocas del Toro", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Panamá Oeste", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Coclé", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Colón", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Chiriquí", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Darién", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Herrera", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Los Santos", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Panamá", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Veraguas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Emberá", region_type=u"indigenous region"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Kuna Yala", region_type=u"indigenous region"),
        list_of_countries_regions(country_id=u"PA", region_name=u"Ngöbe-Buglé", region_type=u"indigenous region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Amazonas", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Ancash", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Apurímac", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Arequipa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Ayacucho", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Cajamarca", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"El Callao", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Cuzco [Cusco]", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Huánuco", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Huancavelica", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Ica", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Junín", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"La Libertad", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Lambayeque", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Lima", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Lima hatun llaqta", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Loreto", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Madre de Dios", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Moquegua", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Pasco", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Piura", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Puno", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"San Martín", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Tacna", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Tumbes", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PE", region_name=u"Ucayali", region_type=u"Region"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Chimbu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Central", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"East New Britain", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Eastern Highlands", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Enga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"East Sepik", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Gulf", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Hela", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Jiwaka", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Milne Bay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Morobe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Madang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Manus", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"National Capital District (Port Moresby)",
                                  region_type=u"District"),
        list_of_countries_regions(country_id=u"PG", region_name=u"New Ireland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Northern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Bougainville", region_type=u"autonomous region"),
        list_of_countries_regions(country_id=u"PG", region_name=u"West Sepik", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Southern Highlands", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"West New Britain", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Western Highlands", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PG", region_name=u"Western", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"National Capital Région (Manila)",
                                  region_type=u"Region"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Abra", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Agusan del Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Agusan del Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Aklan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Albay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Antique", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Apayao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Aurora", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Bataan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Basilan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Benguet", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Biliran", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Bohol", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Batangas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Batanes", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Bukidnon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Bulacan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Cagayan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Camiguin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Camarines Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Capiz", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Camarines Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Catanduanes", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Cavite", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Cebu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Compostela Valley", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Davao Oriental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Davao del Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Davao del Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Dinagat Islands", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Kanlurang Dabaw", region_type=u"province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Eastern Samar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Guimaras", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Ifugao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Iloilo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Ilocos Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Ilocos Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Isabela", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Kalinga-Apayao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Laguna", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Lanao del Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Lanao del Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Leyte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"La Union", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Marinduque", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Maguindanao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Masbate", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Mindoro Occidental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Mindoro Oriental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Mountain Province", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Misamis Occidental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Misamis Oriental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Kotabato", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Negros occidental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Negros oriental", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Northern Samar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Nueva Ecija", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Nueva Vizcaya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Pampanga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Pangasinan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Palawan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Quezon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Quirino", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Rizal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Romblon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Sarangani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"South Cotabato", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Siquijor", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Southern Leyte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Sulu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Sorsogon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Sultan Kudarat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Surigao del Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Surigao del Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Tarlac", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Tawi-Tawi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Western Samar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Zamboanga del Norte", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Zamboanga del Sur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Zambales", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PH", region_name=u"Zamboanga Sibuguey [Zamboanga Sibugay]",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Balochistan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Gilgit-Baltistan",
                                  region_type=u"Pakistan administrered area"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Islamabad",
                                  region_type=u"Federal capital territory"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Azad Kashmir",
                                  region_type=u"Pakistan administrered area"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Khyber Pakhtunkhwa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Punjab", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Sindh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PK", region_name=u"Federally Administered Tribal Areas",
                                  region_type=u"Territory"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Dolnoslaskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Kujawsko-pomorskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Lubuskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Lódzkie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Lubelskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Malopolskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Mazowieckie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Opolskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Podlaskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Podkarpackie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Pomorskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Swietokrzyskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Slaskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Warminsko-mazurskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Wielkopolskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PL", region_name=u"Zachodniopomorskie", region_type=u"Province"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Bethlehem", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Deir El Balah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Gaza", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Hebron", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Jerusalem", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u" Jericho and Al Aghwar",
                                  region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Khan Yunis", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Nablus", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"North Gaza", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Qalqilya", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Ramallah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Rafah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Salfit", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Tubas", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PS", region_name=u"Tulkarm", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Aveiro", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Beja", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Braga", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Bragança", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Castelo Branco", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Coimbra", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Évora", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Faro", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Guarda", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Leiria", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Lisboa", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Portalegre", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Porto", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Santarém", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Setúbal", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Viana do Castelo", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Vila Real", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Viseu", region_type=u"District"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Região Autónoma dos Açores",
                                  region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"PT", region_name=u"Região Autónoma da Madeira",
                                  region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Aimeliik    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Airai       ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Angaur      ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Hatobohei   ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Kayangel    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Koror       ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Melekeok    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngaraard    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngarchelong ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngardmau    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngatpang    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngchesar    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngeremlengui", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Ngiwal      ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Peleliu     ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PW", region_name=u"Sonsorol    ", region_type=u"State"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Concepción", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Alto Paraná", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Central", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Ñeembucú", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Amambay", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Canindeyú", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Presidente Hayes", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Alto Paraguay", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Boquerón", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"San Pedro", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Cordillera", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Guairá", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Caaguazú", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Caazapá", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Itapúa", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Misiones", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Paraguarí", region_type=u"Department"),
        list_of_countries_regions(country_id=u"PY", region_name=u"Asunción", region_type=u"Capital"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Ad Dawhah", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Al Khawr wa adh Dhakhirah",
                                  region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Ash Shamal", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Ar Rayyan", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Umm Salal", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Al Wakrah", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"QA", region_name=u"Az¸ Z¸a‘ayin", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Alba", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Arges", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Arad", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Bucuresti", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Bacau", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Bihor", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Bistrita-Nasaud", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Braila", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Botosani", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Brasov", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Buzau", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Cluj", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Calarasi", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Caras-Severin", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Constarta", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Covasna", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Dâmbovita", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Dolj", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Gorj", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Galati", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Giurgiu", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Hunedoara", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Harghita", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Ilfov", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Ialomita", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Iasi", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Mehedinti", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Maramures", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Mures", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Neamt", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Olt", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Prahova", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Sibiu", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Salaj", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Satu Mare", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Suceava", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Tulcea", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Timis", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Teleorman", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Vâlcea", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Vrancea", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RO", region_name=u"Vaslui", region_type=u"Departments"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Beograd", region_type=u"City"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Severnobacki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Srednjebanatski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Severnobanatski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Južnobanatski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Zapadnobacki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Južnobacki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Sremski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Macvanski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Kolubarski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Podunavski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Branicevski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Šumadijski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Pomoravski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Borski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Zajecarski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Zlatiborski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Moravicki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Raški okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Rasinski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Nišavski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Toplicki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Pirotski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Jablanicki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Pcinjski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Kosovski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Pecki okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Prizrenski okrug", region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Kosovsko-Mitrovacki okrug",
                                  region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Kosovsko-Pomoravski okrug",
                                  region_type=u"District"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Kosovo-Metohija",
                                  region_type=u"Autonomous province"),
        list_of_countries_regions(country_id=u"RS", region_name=u"Vojvodina", region_type=u"Autonomous province"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Adygeya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Altay, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Altayskiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Amurskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Arkhangel'skaya oblast,",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Astrakhanskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Bashkortostan, Respublika",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Belgorodskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Bryanskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Buryatiya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Chechenskaya Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Chelyabinskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Chukotskiy avtonomnyy okrug",
                                  region_type=u"Autonomous district"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Chuvashskaya Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Dagestan, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Ingushskaya Respublika [Respublika Ingushetiya]",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Irkutskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Ivanovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kamchatskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kabardino-Balkarskaya Respublika",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Karachayevo-Cherkesskaya Respublika",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Krasnodarskiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kemerovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kaliningradskaya oblast,",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kurganskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Khabarovskiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Khanty-Mansiyskiy avtonomnyy okrug",
                                  region_type=u"Autonomous district"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kirovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Khakasiya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kalmykiya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kaluzhskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Komi, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kostromskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kareliya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Kurskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Krasnoyarskiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Leningradskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Lipetskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Magadanskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Mariy El, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Mordoviya, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Moskovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Moskva", region_type=u"Autonomous city"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Murmanskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Nenetskiy avtonomnyy okrug",
                                  region_type=u"Autonomous district"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Novgorodskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Nizhegorodskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Novosibirskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Omskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Orenburgskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Orlovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Perm", region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Penzenskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Primorskiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Pskovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Rostovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Ryazanskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Sakha, Respublika [Yakutiya]",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Sakhalinskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Samarskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Saratovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU",
                                  region_name=u"Severnaya Osetiya, Respublika Alaniya] [Respublika Severnaya Osetiya-Alaniya]",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Smolenskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Sankt-Peterburg", region_type=u"Autonomous city"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Stavropol'skiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Sverdlovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tatarstan, Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tambovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tomskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tul'skaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tverskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tyva, Respublika [Tuva]", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Tyumenskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Udmurtskaya Respublika", region_type=u"Republic"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Ul'yanovskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Volgogradskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Vladimirskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Vologodskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Voronezhskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Yamalo-Nenetskiy avtonomnyy okrug",
                                  region_type=u"Autonomous district"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Yaroslavskaya oblast'",
                                  region_type=u"Administrative region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Yevreyskaya avtonomnaya oblast'",
                                  region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"RU", region_name=u"Zabaykal'skiy kray",
                                  region_type=u"Administrative territory"),
        list_of_countries_regions(country_id=u"RW", region_name=u"Ville de Kigali", region_type=u"Town council"),
        list_of_countries_regions(country_id=u"RW", region_name=u"Est", region_type=u"Province"),
        list_of_countries_regions(country_id=u"RW", region_name=u"Nord", region_type=u"Province"),
        list_of_countries_regions(country_id=u"RW", region_name=u"Ouest", region_type=u"Province"),
        list_of_countries_regions(country_id=u"RW", region_name=u"Sud", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Ar Riyad", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Makkah al Mukarramah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Al Madinah al Munawwarah",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Ash Sharqiyah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"AI Qasim", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Ha'il", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Tabuk", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"AI Hudud ash Shamaliyah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Jazan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"Najran", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"AI Bahah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"AI Jawf", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SA", region_name=u"'Asir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Central", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Choiseul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Capital Territory (Honiara)",
                                  region_type=u"Capital territory"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Guadalcanal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Isabel", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Makira-Ulawa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Malaita", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Rennell and Bellona", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Temotu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SB", region_name=u"Western", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Anse aux Pins", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Anse Boileau         ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Anse Étoile          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Au Cap", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Anse Royale          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Baie Lazare          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Baie Sainte Anne     ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Beau Vallon          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Bel Air              ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Bel Ombre            ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Cascade              ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Glacis               ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Grand'Anse Mahé", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Grand'Anse Praslin", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"La Digue             ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"La Rivière Anglaise  ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Mont Buxton          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Mont Fleuri          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Plaisance            ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Pointe La Rue        ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Port Glaud           ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Saint Louis          ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Takamaka             ", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Lemamel", region_type=u"District"),
        list_of_countries_regions(country_id=u"SC", region_name=u"Ros Kaiman", region_type=u"District"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Wasat Darfur Zalinjay", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Sharq Darfur", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Shamal Darfur", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Janub Darfur", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Gharb Darfur", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Al Qadarif", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Gharb Kurdufan", region_type=u"state"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Al Jazirah", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Kassala", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Al Khartum", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Shiamal Kurdufan", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Janub Kurdufan", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"An Nil al Azraq", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Ash Shamaliyah", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Nahr an Nil", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"An Nil al Abya?", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Al Ba?r al A?mar", region_type=u"State"),
        list_of_countries_regions(country_id=u"SD", region_name=u"Sinnar", region_type=u"State"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Stockholms län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Västerbottens län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Norrbottens län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Uppsala län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Södermanlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Östergötlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Jönköpings län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Kronoborgs län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Kalmar län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Gotlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Blekinge län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Skåne län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Hallands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Västra Götalands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Värmlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Örebro län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Västmanlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Dalarnes län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Gävleborgs län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Västernorrlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SE", region_name=u"Jämtlands län", region_type=u"County"),
        list_of_countries_regions(country_id=u"SG", region_name=u"Central Singapore", region_type=u"District"),
        list_of_countries_regions(country_id=u"SG", region_name=u"North East", region_type=u"District"),
        list_of_countries_regions(country_id=u"SG", region_name=u"North West", region_type=u"District"),
        list_of_countries_regions(country_id=u"SG", region_name=u"South East", region_type=u"District"),
        list_of_countries_regions(country_id=u"SG", region_name=u"South West", region_type=u"District"),
        list_of_countries_regions(country_id=u"SH", region_name=u"Ascension", region_type=u"Geographical entity"),
        list_of_countries_regions(country_id=u"SH", region_name=u"Saint Helena", region_type=u"Geographical entity"),
        list_of_countries_regions(country_id=u"SH", region_name=u"Tristan da Cunha",
                                  region_type=u"Geographical entity"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ajdovšcina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Beltinci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Bled", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Bohinj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Borovnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Bovec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Brda", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Brezovica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Brežice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Tišina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Celje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cerklje na Gorenjskem", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cerknica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cerkno", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Crenšovci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Crna na Koroškem", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Crnomelj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Destrnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Divaca", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dobrepolje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dobrova-Polhov Gradec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dol pri Ljubljani", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Domžale", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dornava", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dravograd", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Duplek", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gorenja vas-Poljane", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gorišnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gornja Radgona", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gornji Grad", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gornji Petrovci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Grosuplje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šalovci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Hrastnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Hrpelje-Kozina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Idrija", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ig", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ilirska Bistrica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ivancna Gorica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Izola", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Jesenice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Juršinci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kamnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kanal", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kidricevo", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kobarid", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kobilje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kocevje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Komen", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Koper", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kozje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kranj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kranjska Gora", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Krško", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kungota", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kuzma", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Laško", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Lenart", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Lendava", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Litija", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ljubljana", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ljubno", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ljutomer", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Logatec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Loška dolina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Loški Potok", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Luce", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Lukovica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Majšperk", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Maribor", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Medvode", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mengeš", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Metlika", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mežica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Miren-Kostanjevica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mislinja", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Moravce", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Moravske Toplice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mozirje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Murska Sobota", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Muta", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Naklo", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Nazarje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Nova Gorica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Novo mesto", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Odranci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ormož", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Osilnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Pesnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Piran", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Pivka", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Podcetrtek", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Podvelka", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Postojna", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Preddvor", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ptuj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Puconci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Race-Fram", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Radece", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Radenci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Radlje ob Dravi", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Radovljica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ravne na Koroškem", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ribnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Rogašovci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Rogaška Slatina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Rogatec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ruše", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Semic", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sevnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sežana", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Slovenj Gradec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Slovenska Bistrica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Slovenske Konjice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Starše", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveti Jurij", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šencur", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šentilj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šentjernej", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šentjur", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Škocjan", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Škofja Loka", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Škofljica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šmarje pri Jelšah", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šmartno ob Paki", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šoštanj", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Štore", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Tolmin", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Trbovlje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Trebnje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Tržic", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Turnišce", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Velenje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Velike Lašce", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Videm", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vipava", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vitanje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vodice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vojnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vrhnika", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vuzenica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Zagorje ob Savi", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Zavrc", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Zrece", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Železniki", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Žiri", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Benedikt", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Bistrica ob Sotli", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Bloke", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Braslovce", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cankova", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cerkvenjak", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dobje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dobrna", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dobrovnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Dolenjske Toplice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Grad", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Hajdina", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Hoce-Slivnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Hodoš", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Horjul", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Jezersko", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Komenda", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kostel", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Križevci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Lovrenc na Pohorju", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Markovci", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Miklavž na Dravskem polju",
                                  region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mirna Pec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Oplotnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Podlehnik", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Polzela", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Prebold", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Prevalje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Razkrižje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Ribnica na Pohorju", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Selnica ob Dravi", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sodražica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Solcava", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveta Ana", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveti Andraž v Slovenskih goricah",
                                  region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šempeter-Vrtojba", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Tabor", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Trnovska vas", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Trzin", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Velika Polana", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Veržej", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Vransko", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Žalec", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Žetale", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Žirovnica", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Žužemberk", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šmartno pri Litiji", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Apace", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Cirkulane", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Kosanjevica na Krki", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Makole", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mokronog-Trebelno", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Poljcane", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Renèe-Vogrsko", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Središce ob Dravi", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Straža", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveta Trojica v Slovenskih_x000D_ Goricah",
                                  region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveti Tomaž", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šmarješke Toplice", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Gorje", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Log-Dragomer", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Recica ob Savinji", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Sveti Jurij v Slovenskih Goricah",
                                  region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Šentrupert", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SI", region_name=u"Mirna", region_type=u"Commune"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Banskobystrický kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Bratislavský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Košický kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Nitriansky kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Prešovský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Trnavský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Trenciansky kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SK", region_name=u"Žilinský kraj", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SL", region_name=u"Eastern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SL", region_name=u"Northern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SL", region_name=u"Southern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SL", region_name=u"Western Area (Freetown)", region_type=u"Area"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Acquaviva      ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Chiesanuova    ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Domagnano      ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Faetano        ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Fiorentino     ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Borgo Maggiore ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"San Marino     ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Montegiardino  ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SM", region_name=u"Serravalle     ", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Diourbel", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Dakar", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Fatick", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Kaffrine", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Kolda", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Kédougou", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Kaolack", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Louga", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Matam", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Sédhiou", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Saint-Louis", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Tambacounda", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Thiès", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SN", region_name=u"Ziguinchor", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Awdal", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Bakool", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Banaadir", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Bari", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Bay", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Galguduud", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Gedo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Hiiraan", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Jubbada Dhexe", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Jubbada Hoose", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Mudug", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Nugaal", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Sanaag", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Shabeellaha Dhexe", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Shabeellaha Hoose", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Sool", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Togdheer", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SO", region_name=u"Woqooyi Galbeed", region_type=u"Region"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Brokopondo", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Commewijne", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Coronie", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Marowijne", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Nickerie", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Paramaribo", region_type=u""),
        list_of_countries_regions(country_id=u"SR", region_name=u"Para", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Saramacca", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Sipaliwini", region_type=u"District"),
        list_of_countries_regions(country_id=u"SR", region_name=u"Wanica", region_type=u"District"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Northern Bahr el Ghazal", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Western Bahr el Ghazal", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Central Equatoria", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Eastern Equatoria", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Western Equatoria", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Jonglei", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Lakes", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Upper Nile", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Unity", region_type=u"State"),
        list_of_countries_regions(country_id=u"SS", region_name=u"Warrap", region_type=u"State"),
        list_of_countries_regions(country_id=u"ST", region_name=u"Príncipe", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ST", region_name=u"São Tomé", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Ahuachapán", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Cabañas", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Chalatenango", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Cuscatlán", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"La Libertad", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Morazán", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"La Paz", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Santa Ana", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"San Miguel", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Sonsonate", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"San Salvador", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"San Vicente", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"La Unión", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SV", region_name=u"Usulután", region_type=u"Department"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Dimashq", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Dar'a", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Dayr az Zawr", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"AI Hasakah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Hims", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Halab", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Hamah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Idlib", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"AI Ladhiqiyah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"AI Qunaytirah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Ar Raqqah", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Rif Dimashq", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"As Suwayda'", region_type=u"Province"),
        list_of_countries_regions(country_id=u"SY", region_name=u"Tartus", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Batha", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Ba?r al Ghazal", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Burku", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Chari-Baguirmi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Ennedi-Est", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Ennedi-Ouest", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Guéra", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Hadjer Lamis", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Kanem", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Lac", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Logone-Occidental", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Logone-Oriental", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Mandoul", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Moyen-Chari", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Mayo-Kebbi-Est", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Mayo-Kebbi-Ouest", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Ville de Ndjamena", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Ouaddaï", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Salamat", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Sila", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Tandjilé", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Tibasti", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TD", region_name=u"Wadi Fira", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TG", region_name=u"Centre", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TG", region_name=u"Kara", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TG", region_name=u"Maritime (Région)", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TG", region_name=u"Plateaux", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TG", region_name=u"Savannes", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Krung Thep Maha Nakhon [Bangkok]",
                                  region_type=u"Metropolitan administration"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Samut Prakan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nonthaburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Pathum Thani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phra Nakhon Si Ayutthaya",
                                  region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Ang Thong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Lop Buri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Sing Buri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chai Nat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Saraburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chon Buri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Rayong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chanthaburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Trat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chachoengsao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Prachin Buri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Nayok", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Sa Kaeo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Ratchasima", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Buri Ram", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Surin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Si Sa Ket", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Ubon Ratchathani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Yasothon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chaiyaphum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Amnat Charoen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Bueng Kan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nong Bua Lam Phu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Khon Kaen", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Udon Thani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Loei", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nong Khai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Maha Sarakham", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Roi Et", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Kalasin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Sakon Nakhon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Phanom", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Mukdahan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chiang Mai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Lamphun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Lampang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Uttaradit", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phrae", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phayao", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chiang Rai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Mae Hong Son", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Sawan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Uthai Thani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Kamphaeng Phet", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Tak", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Sukhothai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phitsanulok", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phichit", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phetchabun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Ratchaburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Kanchanaburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Suphan Buri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Pathom", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Samut Sakhon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Samut Songkhram", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phetchaburi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Prachuap Khiri Khan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Nakhon Si Thammarat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Krabi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phangnga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phuket", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Surat Thani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Ranong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Chumphon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Songkhla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Satun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Trang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phatthalung", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Pattani", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Yala", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Narathiwat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TH", region_name=u"Phatthaya",
                                  region_type=u"special administrative_x000D_ Special administrative city"),
        list_of_countries_regions(country_id=u"TJ", region_name=u"Dushanbe", region_type=u"Capital territory"),
        list_of_countries_regions(country_id=u"TJ", region_name=u"Kuhistoni Badakhshon",
                                  region_type=u"Autonomous region"),
        list_of_countries_regions(country_id=u"TJ", region_name=u"Khatlon", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TJ", region_name=u"Sughd", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Aileu", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Ainaro", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Baucau", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Bobonaro", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Cova Lima", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Díli", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Ermera", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Lautem", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Liquiça", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Manufahi", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Manatuto", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Oecussi", region_type=u"District"),
        list_of_countries_regions(country_id=u"TL", region_name=u"Viqueque", region_type=u"District"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Ahal", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Balkan", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Dasoguz", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Lebap", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Mary", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TM", region_name=u"Asgabat", region_type=u"City"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Tunis", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"L'Ariana", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Ben Arous", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"La Manouba", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Nabeul", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Zaghouan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Bizerte", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Béja", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Jendouba", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Le Kef", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Siliana", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Kairouan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Kasserine", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Sidi Bouzid", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Sousse", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Monastir", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Mahdia", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Sfax", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Gafsa", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Tozeur", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u" Kébili", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Gabès", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Médenine", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TN", region_name=u"Tataouine", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"TO", region_name=u"'Eua", region_type=u"Division"),
        list_of_countries_regions(country_id=u"TO", region_name=u"Ha'apai", region_type=u"Division"),
        list_of_countries_regions(country_id=u"TO", region_name=u"Niuas", region_type=u"Division"),
        list_of_countries_regions(country_id=u"TO", region_name=u"Tongatapu", region_type=u"Division"),
        list_of_countries_regions(country_id=u"TO", region_name=u"Vava'u", region_type=u"Division"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Adana", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Adiyaman", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Afyonkarahisar", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Agri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Amasya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Ankara", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Antalya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Artvin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Aydin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Balikesir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bilecik", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bingöl", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bitlis", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bolu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Burdur", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bursa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Canakkale", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Çankiri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Corum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Denizli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Diyarbakir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Edirne", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Elazig", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Erzincan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Erzurum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Eskisehir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Gaziantep", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Giresun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Gümüshane", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Hakkari", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Hatay", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Isparta", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Mersin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Istanbul", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Izmir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kars", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kastamonu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kayseri", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kirklareli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kirsehir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kocaeli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Konya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kütahya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Malatya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Manisa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kahramanmaras", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Mardin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Mugla", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Mus", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Nevsehir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Nigde", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Ordu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Rize", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Sakarya", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Samsun", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Siirt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Sinop", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Sivas", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Tekirdag", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Tokat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Trabzon", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Tunceli", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Sanliurfa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Usak", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Van", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Yozgat", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Zonguldak", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Aksaray", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bayburt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Karaman", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kirikkale", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Batman", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Sirnak", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Bartin", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Ardahan", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Igdir", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Yalova", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Karabuk", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Kilis", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Osmaniye", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TR", region_name=u"Düzce", region_type=u"Province"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Arima", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Chaguanas", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Couva-Tabaquite-Talparo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Diego Martin", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Mayaro-Rio Claro", region_type=u"region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Penal-Debe", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Port of Spain", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Princes Town", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Point Fortin", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TT", region_name=u"San Fernando", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Sangre Grande", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Siparia", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"San Juan-Laventille", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Tobago", region_type=u"ward"),
        list_of_countries_regions(country_id=u"TT", region_name=u"Tunapuna-Piarco", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Funafuti", region_type=u"Town council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Niutao", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Nui", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Nukufetau", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Nukulaelae", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Nanumea", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Nanumanga", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TV", region_name=u"Vaitupu", region_type=u"Island council"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Changhua", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Chiayi", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Chiayi", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Hsinchu", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Hsinchu", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Hualien", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Yilan", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Keelung", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Kaohsiung", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Kinmen", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Lienchiang", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Miaoli", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Nantou", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"New Taipei", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Penghu", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Pingtung", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Taoyuan", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Tainan", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Taipei", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Taitung", region_type=u"district"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Taichung", region_type=u"special municipality"),
        list_of_countries_regions(country_id=u"TW", region_name=u"Yunlin", region_type=u"district"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Arusha", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Dar es Salaam", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Dodoma", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Iringa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kagera", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kaskazini Pemba", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kaskazini Unguja", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kigoma", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kilimanjaro", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kusini Pemba", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Kusini Unguja", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Lindi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Mara", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Mbeya", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Mjini Magharibi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Morogoro", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Mtwara", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Mwanza", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Pwani", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Rukwa", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Ruvuma", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Shinyanga", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Singida", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Tabora", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Tanga", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Manyara", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Geita", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Katavi", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Njombe", region_type=u"Region"),
        list_of_countries_regions(country_id=u"TZ", region_name=u"Simiyu", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Vinnytska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Volynska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Luhanska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Dnipropetrovska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Donetska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Zhytomyrska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Zakarpatska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Zaporizka oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Ivano-Frankivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Kyiv", region_type=u"City"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Kyivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Kirovohradska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Sevastopol", region_type=u"City"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Avtonomna Respublika Krym",
                                  region_type=u"Republic"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Lvivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Mykolaivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Odeska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Poltavska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Rivnenska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Sumska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Ternopilska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Kharkivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Khersonska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Khmelnytska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Cherkaska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Chernihivska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UA", region_name=u"Chernivetska oblast", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kalangala", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kampala", region_type=u"City"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kiboga", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Luwero", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Masaka", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mpigi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mubende", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mukono", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Nakasongola", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Rakai", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Sembabule", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kayunga", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Wakiso", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mityana", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Nakaseke", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Lyantonde", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Buikwe", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bukomansibi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Butambala", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Buvuma", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Gomba", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kalungu", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kyankwanzi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Lwengo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bugiri", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Busia", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Iganga", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Jinja", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kamuli", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kapchorwa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Katakwi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kumi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mbale", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Pallisa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Soroti", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Tororo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kaberamaido", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Sironko", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Amuria", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Budaka", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bukwa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Butaleja", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kaliro", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Manafwa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Namutumba", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bududa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bukedea", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bulambuli", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Buyende", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kibuku", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kween", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Luuka", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Namayingo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Ngora", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Serere", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mayuge", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Adjumani", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Apac", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Arua", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Gulu", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kitgum", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kotido", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Lira", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Moroto", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Moyo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Nebbi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Nakapiripirit", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Pader", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Yumbe", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Amolatar", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kaabong", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Koboko", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Abim", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Dokolo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Amuru", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Maracha", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Oyam", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bundibugyo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Bushenyi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Hoima", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kabale", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kabarole", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kasese", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kibaale", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kisoro", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Masindi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mbarara", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Ntungamo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Rukungiri", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kamwenge", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kanungu", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kyenjojo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Ibanda", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Isingiro", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kiruhura", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Buliisa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kiryandongo", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Kyegegwa", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Mitooma", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Ntoroko", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Rubirizi", region_type=u"District"),
        list_of_countries_regions(country_id=u"UG", region_name=u"Sheema", region_type=u"District"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Johnston Atoll (ISO reserved code = JT)",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Midway Islands (ISO reserved code = I)",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Navassa Island (ISO reserved code = NV)",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Wake Island (ISO reserved code = WK)",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Baker Island",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Howland Island",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Jarvis Island",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Kingman Reef",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"UM", region_name=u"Palmyra Atoll",
                                  region_type=u"Islands/Groups of Islands"),
        list_of_countries_regions(country_id=u"US", region_name=u"Alaska", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Alabama", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Arkansas", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"American Samoa (see also separate entry under AS)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Arizona", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"California", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Colorado", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Connecticut", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"District of Columbia", region_type=u"District"),
        list_of_countries_regions(country_id=u"US", region_name=u"Delaware", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Florida", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Georgia", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Guam (see also separate entry under GU)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Hawaii", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Iowa", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Idaho", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Illinois", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Indiana", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Kansas", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Kentucky", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Louisiana", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Massachusetts", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Maryland", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Maine", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Michigan", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Minnesota", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Missouri", region_type=u"State"),
        list_of_countries_regions(country_id=u"US",
                                  region_name=u"Northern Mariana Islands (see also separate entry MP)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Mississippi", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Montana", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"North Carolina", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"North Dakota", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Nebraska", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"New Hampshire", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"New Jersey", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"New Mexico", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Nevada", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"New York", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Ohio", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Oklahoma", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Oregon", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Pennsylvania", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Puerto Rico (see also separate entry under PR)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Rhode Island", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"South Carolina", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"South Dakota", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Tennessee", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Texas", region_type=u"State"),
        list_of_countries_regions(country_id=u"US",
                                  region_name=u"U.S. Minor Outlying Islands (cf. separate entry UM)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Utah", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Virginia", region_type=u"State"),
        list_of_countries_regions(country_id=u"US",
                                  region_name=u"Virgin Islands of the U.S. (see also separate entry VI)",
                                  region_type=u"Outlying area"),
        list_of_countries_regions(country_id=u"US", region_name=u"Vermont", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Washington", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Wisconsin", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"West Virginia", region_type=u"State"),
        list_of_countries_regions(country_id=u"US", region_name=u"Wyoming", region_type=u"State"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Artigas", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Canelones", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Cerro Largo", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Colonia", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Durazno", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Florida", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Flores", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Lavalleja", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Maldonado", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Montevideo", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Paysandú", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Río Negro", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Rocha", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Rivera", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Salto", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"San José", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Soriano", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Tacuarembó", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UY", region_name=u"Treinta y Tres", region_type=u"Department"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Andijon", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Bukhoro", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Farg‘ona", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Jizzax", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Khorazm", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Namangan", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Nawoiy", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Qashqadaryo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Qoraqalpog‘iston Respublikasi",region_type=u"Republic"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Samarqand", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Sirdaryo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Surkhondaryo", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Toshkent", region_type=u"City"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Toshkent", region_type=u"Region"),
        list_of_countries_regions(country_id=u"UZ", region_name=u"Xorazm", region_type=u"Region"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Charlotte     ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Saint Andrew  ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Saint David   ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Saint George  ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Saint Patrick ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VC", region_name=u"Grenadines    ", region_type=u"Parish"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Distrito Capital",region_type=u"Capital district"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Anzoátegui", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Apure", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Aragua", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Barinas", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Bolívar", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Carabobo", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Cojedes", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Falcón", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Guárico", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Lara", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Mérida", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Miranda", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Monagas", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Nueva Esparta", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Portuguesa", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Sucre", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Táchira", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Trujillo", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Yaracuy", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Zulia", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Dependencias Federales",region_type=u"Federal dependencies"),
        list_of_countries_regions(country_id=u"VE", region_name=u"vargas", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Delta Amacuro", region_type=u"State"),
        list_of_countries_regions(country_id=u"VE", region_name=u"Amazonas", region_type=u"State"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Lai Châu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Lào Cai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hà Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Cao B?ng", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Son La", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Yên Bái", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Tuyên Quang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"L?ng Son", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Qu?ng Ninh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hòa Bình", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ninh Bình", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Thái Bình", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Thanh Hóa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ngh? An", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hà Tinh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Qu?ng Bình", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Qu?ng Tr?", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Th?a Thiên-Hu?", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Qu?ng Nam", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Kon Tum", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Qu?ng Ngãi", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Gia Lai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Bình Ð?nh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Phú Yên", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ð?k L?k", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Khánh Hòa", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Lâm Ð?ng", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ninh Thu?n", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Tây Ninh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ð?ng Nai", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Bình Thu?n", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Long An", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Bà R?a - Vung Tàu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"An Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ð?ng Tháp", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ti?n Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ki?n Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Vinh Long", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"B?n Tre", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Trà Vinh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Sóc Trang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"B?c K?n", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"B?c Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"B?c Liêu", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"B?c Ninh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Bình Duong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Bình Phu?c", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Cà Mau", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"H?i Duong", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hà Nam", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hung Yên", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Nam Ð?nh", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Phú Th?", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Thái Nguyên", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Vinh Phúc", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ði?n Biên", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ð?k Nông", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"H?u Giang", region_type=u"Province"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Can Tho", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Da Nang, thanh pho", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ha Noi", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Hai Phong", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"VN", region_name=u"Ho Chi Minh", region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"VU", region_name=u"Malampa", region_type=u""),
        list_of_countries_regions(country_id=u"VU", region_name=u"Pénama", region_type=u""),
        list_of_countries_regions(country_id=u"VU", region_name=u"Sanma", region_type=u""),
        list_of_countries_regions(country_id=u"VU", region_name=u"Shéfa", region_type=u""),
        list_of_countries_regions(country_id=u"VU", region_name=u"Taféa", region_type=u""),
        list_of_countries_regions(country_id=u"VU", region_name=u"Torba", region_type=u""),
        list_of_countries_regions(country_id=u"WS", region_name=u"A'ana", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Aiga-i-le-Tai", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Atua", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Fa'asaleleaga", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Gaga'emauga", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Gagaifomauga", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Palauli", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Satupa 'itea", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Tuamasaga", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Va'a-o-Fonoti", region_type=u"District"),
        list_of_countries_regions(country_id=u"WS", region_name=u"Vaisigano", region_type=u"District"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Abyan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"‘Adan", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"‘Amran", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Al Bay?a’", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u" A? ?ali‘", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Dhamar", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"?a?ramawt", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"?ajjah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Al ?udaydah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Ibb", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Al Jawf", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Lahij", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Ma’rib", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Al Mahrah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Al Ma?wit", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Raymah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Amanat al ‘Asimah [city]",region_type=u"Municipality"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Sa'dah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Shabwah", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"San?a'", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Arkhabil Suqutrá", region_type=u"governorate"),
        list_of_countries_regions(country_id=u"YE", region_name=u"Ta'izz", region_type=u"Governorate"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Eastern Cape", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Free State", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Gauteng", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Limpopo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Mpumalanga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Northern Cape", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Kwazulu-Natal", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"North-West", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZA", region_name=u"Western Cape", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Western", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Central", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Eastern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Luapula", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Northern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"North-Western", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Southern", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Copperbelt", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Lusaka", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZM", region_name=u"Muchinga", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Bulawayo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Harare", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Manicaland", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Mashonaland Central", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Mashonaland East", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Midlands", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Matabeleland North", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Matabeleland South", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Masvingo", region_type=u"Province"),
        list_of_countries_regions(country_id=u"ZW", region_name=u"Mashonaland West", region_type=u"Province"),
    ])


    list_of_quote_stages = apps.get_model("NearBeach", "list_of_quote_stage")
    db_alias = schema_editor.connection.alias
    list_of_quote_stages.objects.using(db_alias).bulk_create([
        #Quote Stage
        list_of_quote_stages(quote_stage="Quote Draft",is_invoice=False,sort_order=1),
        list_of_quote_stages(quote_stage="Quote Negotiation",is_invoice=False,sort_order=2),
        list_of_quote_stages(quote_stage="Quote Delivered",is_invoice=False,sort_order=3),
        list_of_quote_stages(quote_stage="Quote On Hold",is_invoice=False,sort_order=4),
        list_of_quote_stages(quote_stage="Quote Confirmed",is_invoice=False,sort_order=5),
        list_of_quote_stages(quote_stage="Quote Close Accepted",is_invoice=False,sort_order=6,quote_closed=True),
        list_of_quote_stages(quote_stage="Quote Close Rejected",is_invoice=False,sort_order=7,quote_closed=True),
        list_of_quote_stages(quote_stage="Quote Close Lost",is_invoice=False,sort_order=8,quote_closed=True),
        list_of_quote_stages(quote_stage="Quote Close Dead",is_invoice=False,sort_order=9,quote_closed=True),
        #Invoice Stage
        list_of_quote_stages(quote_stage="Invoice Draft",is_invoice=True,sort_order=10),
        list_of_quote_stages(quote_stage="Invoice Negotiation",is_invoice=True,sort_order=11),
        list_of_quote_stages(quote_stage="Invoice Delivered",is_invoice=True,sort_order=12),
        list_of_quote_stages(quote_stage="Invoice On Hold",is_invoice=True,sort_order=13),
        list_of_quote_stages(quote_stage="Invoice Confirmed",is_invoice=True,sort_order=14),
        list_of_quote_stages(quote_stage="Invoice Close Accepted",is_invoice=True,sort_order=15,quote_closed=True),
        list_of_quote_stages(quote_stage="Invoice Close Rejected",is_invoice=True,sort_order=16,quote_closed=True),
        list_of_quote_stages(quote_stage="Invoice Close Lost",is_invoice=True,sort_order=17,quote_closed=True),
        list_of_quote_stages(quote_stage="Invoice Close Dead",is_invoice=True,sort_order=18,quote_closed=True),
    ])

    nearbeach_option = apps.get_model("NearBeach","nearbeach_option")
    db_alias = schema_editor.connection.alias
    nearbeach_option.objects.using(db_alias).bulk_create([
        nearbeach_option(story_point_hour_min=4,story_point_hour_max=10),
    ])


class Migration(migrations.Migration):

    dependencies = [
        ('NearBeach', '0001_initial'),
    ]

    operations = [
		migrations.RunPython(initialise_data),
    ]
